@@ -19,18 +19,14 @@ Example
         documents_path: path/to/a/document.json
 """
 
-import sys
+from functools import cached_property
 
 from attrs import define
+
 from logprep.abc.input import Input
 from logprep.connector.dummy.input import DummyInput
 from logprep.util.json_handling import parse_json
 
-if sys.version_info.minor < 8:  # pragma: no cover
-    from backports.cached_property import cached_property  # pylint: disable=import-error
-else:
-    from functools import cached_property
-
 
 class JsonInput(DummyInput):
     """JsonInput Connector"""
