@@ -19,15 +19,11 @@ Example
         documents_path: path/to/a/document.jsonl
 
 """
-import sys
+from functools import cached_property
+
 from logprep.connector.json.input import JsonInput
 from logprep.util.json_handling import parse_jsonl
 
-if sys.version_info.minor < 8:  # pragma: no cover
-    from backports.cached_property import cached_property  # pylint: disable=import-error
-else:
-    from functools import cached_property
-
 
 class JsonlInput(JsonInput):
     """JsonlInput Connector"""
