@@ -35,6 +35,7 @@ class PipelineManager:
 
         self._lock = Lock()
         self._shared_dict = None
+        self._used_server_ports = None
 
     def set_configuration(self, configuration: Configuration):
         """Verify the configuration and set it in the pipeline manager."""
@@ -43,6 +44,7 @@ class PipelineManager:
 
         manager = Manager()
         self._shared_dict = manager.dict()
+        self._used_server_ports = manager.dict()
         for idx in range(configuration["process_count"]):
             self._shared_dict[idx] = None
 
@@ -85,23 +87,9 @@ class PipelineManager:
             pipeline.stop()
             pipeline.join()
 
-    def replace_pipelines(self):
-        """Replace one pipeline at a time."""
-        for index, _ in enumerate(self._pipelines):
-            old_pipeline = self._pipelines[index]
-            old_pipeline.stop()
-            old_pipeline.join()
-
-            self._pipelines[index] = self._create_pipeline(index)
-            self._pipelines[index].start()
-
-    def remove_failed_pipeline(self):
+    def restart_failed_pipeline(self):
         """Remove one pipeline at a time."""
-        failed_pipelines = []
-        for pipeline in self._pipelines:
-            if not pipeline.is_alive():
-                failed_pipelines.append(pipeline)
-
+        failed_pipelines = [pipeline for pipeline in self._pipelines if not pipeline.is_alive()]
         for failed_pipeline in failed_pipelines:
             self._pipelines.remove(failed_pipeline)
 
@@ -111,7 +99,8 @@ class PipelineManager:
                 )
 
         if failed_pipelines:
-            self._logger.warning(f"Removed {len(failed_pipelines)} failed pipeline(s)")
+            self.set_count(self._configuration.get("process_count"))
+            self._logger.warning(f"Restarted {len(failed_pipelines)} failed pipeline(s)")
 
     def handle_logs_into_logger(self, logger: Logger, timeout: float):
         """Handle logs."""
@@ -137,5 +126,6 @@ class PipelineManager:
             log_handler=self._log_handler,
             lock=self._lock,
             shared_dict=self._shared_dict,
+            used_server_ports=self._used_server_ports,
             metric_targets=self.metric_targets,
         )
