@@ -89,6 +89,44 @@ Further details can be found in the section for processors.
         "description": "..."
       }
     ]
+
+Log message field value access
+==============================
+
+All rules reference fields or field values of log messages.
+This can be done via the **dot notation**.
+To reference a nested field inside the log event, just give the whole path from the event root
+to the desired field.
+To reference the field :code:`information` in the following example you would use the following
+notation: :code:`more.nested.information`.
+If you do want to access a specific item inside a list of the event you can extend the dotted
+notation with indices.
+Given the following example you can access the list element :code:`lists` with the following
+notation: :code:`more.nested.sometimes.1`.
+In case you want to have more than one element then you can slice the list with the pattern
+:code:`start:stop:step_size`, e.g: :code:`more.nested.sometimes.0:2` which would return
+:code:`["inside", "lists"]`.
+This slicing is based on the native
+`python list slicing <https://docs.python.org/3/library/functions.html#slice>`_.
+
+..  code-block:: json
+    :linenos:
+    :caption: Example Event
+
+    {
+      "some": "data",
+      "more": {
+        "nested": {
+          "information": "is here",
+          "sometimes": ["inside", "lists", "of", "elements"]
+        }
+      }
+    }
+
+.. WARNING::
+   The dotted field notation is available in all processors, the use of indices to access list
+   elements is though not available in the :code:`Clusterer`, :code:`Labeler` and the
+   :code:`Pseudonymizer`.
 """
 
 import json
@@ -96,14 +134,13 @@ from os.path import basename, splitext
 from typing import List, Set, Optional, Dict
 
 from attrs import define, field, validators
-
 from ruamel.yaml import YAML
 
-from logprep.metrics.metric import Metric, calculate_new_average
 from logprep.filter.expression.filter_expression import FilterExpression
 from logprep.filter.lucene_filter import LuceneFilter
+from logprep.metrics.metric import Metric, calculate_new_average
 from logprep.processor.base.exceptions import InvalidRuleDefinitionError
-from logprep.util.json_handling import is_json
+from logprep.util.getter import GetterFactory
 from logprep.util.helper import camel_to_snake
 
 yaml = YAML(typ="safe", pure=True)
@@ -213,24 +250,18 @@ class Rule:
     # pylint: enable=C0111
 
     @classmethod
-    def create_rules_from_file(cls, path: str) -> list:
+    def create_rules_from_target(cls, path: str) -> list:
         """Create a rule from a file."""
-        is_valid_json = is_json(path)
-        rule_data = None
-        with open(path, "r", encoding="utf8") as file:
-            if is_valid_json:
-                rule_data = json.load(file)
-            else:
-                rule_data = yaml.load_all(file)
-            # needs to be executed in context manager of open, because
-            # `yaml.load_all` returns a generator and read operation happens in
-            # this list comprehension which leads to an I/O Error otherwise
-            rules = [cls._create_from_dict(rule) for rule in rule_data]
+        content = GetterFactory.from_string(path).get()
+        try:
+            rule_data = json.loads(content)
+        except ValueError:
+            rule_data = yaml.load_all(content)
+        rules = [cls._create_from_dict(rule) for rule in rule_data]
         if len(rules) == 0:
             raise InvalidRuleDefinitionError("no rules in file")
         for rule in rules:
             rule.file_name = splitext(basename(path))[0]
-
         return rules
 
     @classmethod
