@@ -14,7 +14,9 @@ The example below deletes the log message if the message field equals "foo".
     description: '...'
 """
 import warnings
+
 from attrs import define, field, validators
+
 from logprep.processor.base.rule import Rule
 from logprep.util.helper import pop_dotted_field_value, add_and_overwrite
 
@@ -33,12 +35,12 @@ class DeleterRule(Rule):
     def normalize_rule_dict(cls, rule: dict) -> None:
         if rule.get("deleter") is None:
             deleter_config = pop_dotted_field_value(rule, "delete")
-        if deleter_config is not None:
-            add_and_overwrite(rule, "deleter.delete", deleter_config)
-            warnings.warn(
-                ("delete is deprecated. " "Use deleter.delete instead"),
-                DeprecationWarning,
-            )
+            if deleter_config is not None:
+                add_and_overwrite(rule, "deleter.delete", deleter_config)
+                warnings.warn(
+                    "delete is deprecated. Use deleter.delete instead",
+                    DeprecationWarning,
+                )
 
     @property
     def delete_event(self) -> bool:
