@@ -26,25 +26,21 @@ Example
         tld_lists: /path/to/list/file
         tagging_field_name: resolved
 """
-import sys
 import ipaddress
-
+from functools import cached_property
+from multiprocessing import current_process
+from pathlib import Path
 from typing import Optional
-from attr import define, field, validators
 
+from attr import define, field, validators
 from tldextract import TLDExtract
 
-
-from logprep.abc import Processor
+from logprep.abc.processor import Processor
 from logprep.processor.base.exceptions import DuplicationError
-from logprep.util.validators import list_of_urls_validator
 from logprep.processor.domain_label_extractor.rule import DomainLabelExtractorRule
+from logprep.util.getter import GetterFactory
 from logprep.util.helper import add_field_to, get_dotted_field_value
-
-if sys.version_info.minor < 8:  # pragma: no cover
-    from backports.cached_property import cached_property  # pylint: disable=import-error
-else:
-    from functools import cached_property
+from logprep.util.validators import list_of_urls_validator
 
 
 class DomainLabelExtractor(Processor):
@@ -78,6 +74,19 @@ class DomainLabelExtractor(Processor):
             _tld_extractor = TLDExtract()
         return _tld_extractor
 
+    def setup(self):
+        super().setup()
+        if self._config.tld_lists:
+            downloaded_tld_lists_paths = []
+            self._logger.debug("start tldlists download...")
+            for index, tld_list in enumerate(self._config.tld_lists):
+                list_path = Path(f"{current_process().name}-{self.name}-tldlist-{index}.dat")
+                list_path.touch()
+                list_path.write_bytes(GetterFactory.from_string(tld_list).get_raw())
+                downloaded_tld_lists_paths.append(f"file://{str(list_path.absolute())}")
+            self._config.tld_lists = downloaded_tld_lists_paths
+            self._logger.debug("finished tldlists download...")
+
     def _apply_rules(self, event, rule: DomainLabelExtractorRule):
         """
         Apply matching rule to given log event. Such that a given domain,
