@@ -26,29 +26,26 @@ Example
         debug_cache: false
 """
 import datetime
-import sys
+from pathlib import Path
 import socket
+from functools import cached_property
 from logging import Logger
-from multiprocessing import context
+from multiprocessing import context, current_process
 from multiprocessing.pool import ThreadPool
 from typing import Optional
-from attr import define, field, validators
 
+from attr import define, field, validators
 from tldextract import TLDExtract
 
-from logprep.abc import Processor
+from logprep.abc.processor import Processor
 from logprep.processor.base.exceptions import DuplicationError
 from logprep.processor.domain_resolver.rule import DomainResolverRule
 from logprep.util.cache import Cache
+from logprep.util.getter import GetterFactory
 from logprep.util.hasher import SHA256Hasher
 from logprep.util.helper import add_field_to, get_dotted_field_value
 from logprep.util.validators import list_of_urls_validator
 
-if sys.version_info.minor < 8:  # pragma: no cover
-    from backports.cached_property import cached_property  # pylint: disable=import-error
-else:
-    from functools import cached_property
-
 
 class DomainResolver(Processor):
     """Resolve domains."""
@@ -143,6 +140,19 @@ class DomainResolver(Processor):
             return TLDExtract(suffix_list_urls=self._config.tld_lists)
         return TLDExtract()
 
+    def setup(self):
+        super().setup()
+        if self._config.tld_lists:
+            downloaded_tld_lists_paths = []
+            self._logger.debug("start tldlists download...")
+            for index, tld_list in enumerate(self._config.tld_lists):
+                list_path = Path(f"{current_process().name}-{self.name}-tldlist-{index}.dat")
+                list_path.touch()
+                list_path.write_bytes(GetterFactory.from_string(tld_list).get_raw())
+                downloaded_tld_lists_paths.append(f"file://{str(list_path.absolute())}")
+            self._config.tld_lists = downloaded_tld_lists_paths
+            self._logger.debug("finished tldlists download...")
+
     def _apply_rules(self, event, rule):
         source_field = rule.source_fields[0]
         target_field = rule.target_field
@@ -164,14 +174,18 @@ class DomainResolver(Processor):
             else:
                 resolved_ip = self._domain_ip_map.get(hash_string)
                 self.metrics.resolved_cached += 1
-            self._add_resolve_infos_to_event(event, target_field, resolved_ip, overwrite_target)
+            self._add_resolve_infos_to_event(
+                event, rule, target_field, resolved_ip, overwrite_target
+            )
             if self._config.debug_cache:
                 self._store_debug_infos(event, requires_storing)
         else:
             resolved_ip = self._resolve_ip(domain)
-            self._add_resolve_infos_to_event(event, target_field, resolved_ip, overwrite_target)
+            self._add_resolve_infos_to_event(
+                event, rule, target_field, resolved_ip, overwrite_target
+            )
 
-    def _add_resolve_infos_to_event(self, event, output_field, resolved_ip, overwrite_target):
+    def _add_resolve_infos_to_event(self, event, _, output_field, resolved_ip, overwrite_target):
         if resolved_ip:
             adding_was_successful = add_field_to(
                 event, output_field, resolved_ip, overwrite_output_field=overwrite_target
