@@ -18,16 +18,13 @@ Example
 """
 import re
 from logging import Logger
-from typing import List
 
-from ruamel.yaml import YAML
-
-from logprep.abc import Processor
+from logprep.abc.processor import Processor
+from logprep.processor.base.exceptions import DuplicationError
 from logprep.processor.generic_resolver.rule import GenericResolverRule
+from logprep.util.getter import GetterFactory
 from logprep.util.helper import get_dotted_field_value
 
-yaml = YAML(typ="safe", pure=True)
-
 
 class GenericResolverError(BaseException):
     """Base class for GenericResolver related exceptions."""
@@ -36,18 +33,6 @@ class GenericResolverError(BaseException):
         super().__init__(f"GenericResolver ({name}): {message}")
 
 
-class DuplicationError(GenericResolverError):
-    """Raise if field already exists."""
-
-    def __init__(self, name: str, skipped_fields: List[str]):
-        message = (
-            "The following fields already existed and were not overwritten by the Normalizer: "
-        )
-        message += " ".join(skipped_fields)
-
-        super().__init__(name, message)
-
-
 class GenericResolver(Processor):
     """Resolve values in documents by referencing a mapping list."""
 
@@ -135,19 +120,18 @@ class GenericResolver(Processor):
         if rule.resolve_from_file:
             if rule.resolve_from_file["path"] not in self._replacements_from_file:
                 try:
-                    with open(rule.resolve_from_file["path"], "r", encoding="utf8") as add_file:
-                        add_dict = yaml.load(add_file)
-                        if isinstance(add_dict, dict) and all(
-                            isinstance(value, str) for value in add_dict.values()
-                        ):
-                            self._replacements_from_file[rule.resolve_from_file["path"]] = add_dict
-                        else:
-                            raise GenericResolverError(
-                                self.name,
-                                f"Additions file "
-                                f'\'{rule.resolve_from_file["path"]}\''
-                                f" must be a dictionary with string values!",
-                            )
+                    add_dict = GetterFactory.from_string(rule.resolve_from_file["path"]).get_yaml()
+                    if isinstance(add_dict, dict) and all(
+                        isinstance(value, str) for value in add_dict.values()
+                    ):
+                        self._replacements_from_file[rule.resolve_from_file["path"]] = add_dict
+                    else:
+                        raise GenericResolverError(
+                            self.name,
+                            f"Additions file "
+                            f'\'{rule.resolve_from_file["path"]}\''
+                            f" must be a dictionary with string values!",
+                        )
                 except FileNotFoundError as error:
                     raise GenericResolverError(
                         self.name,
