@@ -18,14 +18,12 @@ if a database compiled from a rule's :code:`resolve_list` should be stored persi
 """
 import re
 from typing import Tuple
-from attrs import define, field, validators
 
-from ruamel.yaml import YAML
+from attrs import define, field, validators
 
 from logprep.processor.base.rule import Rule, InvalidRuleDefinitionError
 from logprep.processor.generic_resolver.rule import GenericResolverRule
-
-yaml = YAML(typ="safe", pure=True)
+from logprep.util.getter import GetterFactory
 
 
 class HyperscanResolverRuleError(InvalidRuleDefinitionError):
@@ -64,7 +62,7 @@ class HyperscanResolverRule(Rule):
             eq=False,
         )
         """A YML file with a resolve list and an optional regex pattern can
-        be used to resolve values.
+        be used to resolve values (for string format see :ref:`getters`).
         For this, either a field :code:`resolve_from_file` with a path to a resolve list
         file must be added or dictionary field :code:`resolve_from_file` with the subfields
         :code:`path` and :code:`pattern`.
@@ -82,18 +80,17 @@ class HyperscanResolverRule(Rule):
         def _init_resolve_from_file(self):
             pattern, resolve_file_path = self._get_resolve_file_path_and_pattern()
             try:
-                with open(resolve_file_path, "r", encoding="utf8") as add_file:
-                    add_dict = yaml.load(add_file)
+                add_dict = GetterFactory.from_string(resolve_file_path).get_yaml()
 
-                    if isinstance(add_dict, dict) and all(
-                        isinstance(value, str) for value in add_dict.values()
-                    ):
-                        self._add_dict_to_resolve_list(add_dict, pattern)
-                    else:
-                        raise InvalidHyperscanResolverDefinition(
-                            f"Additions file '{self.resolve_from_file} must be a dictionary with "
-                            f"string values!"
-                        )
+                if isinstance(add_dict, dict) and all(
+                    isinstance(value, str) for value in add_dict.values()
+                ):
+                    self._add_dict_to_resolve_list(add_dict, pattern)
+                else:
+                    raise InvalidHyperscanResolverDefinition(
+                        f"Additions file '{self.resolve_from_file} must be a dictionary with "
+                        f"string values!"
+                    )
             except FileNotFoundError as error:
                 raise InvalidHyperscanResolverDefinition(
                     f"Additions file '{self.resolve_from_file}' not found!"
