@@ -21,13 +21,12 @@ Example
 """
 from logging import Logger
 
-from attr import define, field
+from attr import define, field, validators
 
-from logprep.abc import Processor
+from logprep.abc.processor import Processor
+from logprep.processor.base.exceptions import DuplicationError
 from logprep.processor.list_comparison.rule import ListComparisonRule
 from logprep.util.helper import add_field_to, get_dotted_field_value
-from logprep.util.validators import directory_validator
-from logprep.processor.base.exceptions import DuplicationError
 
 
 class ListComparisonError(BaseException):
@@ -44,9 +43,12 @@ class ListComparison(Processor):
     class Config(Processor.Config):
         """ListComparison config"""
 
-        list_search_base_path: str = field(validator=directory_validator)
+        list_search_base_path: str = field(validator=validators.instance_of(str))
         """Relative list paths in rules will be relative to this path if this is set.
-        This parameter is optional."""
+        This parameter is optional. For string format see :ref:`getters`.
+        You can also pass a template with keys from environment,
+        e.g.,  :code:`${<your environment variable>}`. The special key :code:`${LOGPREP_LIST}`
+        will be filled by this processor. """
 
     rule_class = ListComparisonRule
 
