@@ -3,8 +3,8 @@ List Comparison
 ===============
 
 The list comparison enricher requires the additional field :code:`list_comparison`.
-The mandatory keys under :code:`list_comparison` are :code:`source_fields` (as list with one element)
-and :code:`target_field`. Former
+The mandatory keys under :code:`list_comparison` are :code:`source_fields`
+(as list with one element) and :code:`target_field`. Former
 is used to identify the field which is to be checked against the provided lists.
 And the latter is used to define the parent field where the results should
 be written to. Both fields can be dotted subfields.
@@ -35,13 +35,16 @@ target field :code:`List_comparison.example`.
     Currently it is not possible to check in more than one source_field per rule
 
 """
+import os.path
+from string import Template
 import warnings
-from pathlib import Path
 from typing import List, Optional
-from attrs import define, field, validators
-from logprep.filter.expression.filter_expression import FilterExpression
 
+from attrs import define, field, validators
+
+from logprep.filter.expression.filter_expression import FilterExpression
 from logprep.processor.field_manager.rule import FieldManagerRule
+from logprep.util.getter import GetterFactory
 from logprep.util.helper import pop_dotted_field_value, add_and_overwrite
 
 
@@ -54,15 +57,15 @@ class ListComparisonRule(FieldManagerRule):
     class Config(FieldManagerRule.Config):
         """RuleConfig for ListComparisonRule"""
 
-        list_file_paths: List[Path] = field(
-            validator=validators.deep_iterable(member_validator=validators.instance_of(Path)),
-            converter=lambda paths: [Path(path) for path in paths],
+        list_file_paths: List[str] = field(
+            validator=validators.deep_iterable(member_validator=validators.instance_of(str))
         )
-        """List of files in relative or absolute notation"""
-        list_search_base_path: Path = field(
-            validator=validators.instance_of(Path), factory=Path, converter=Path
-        )
-        """Base Path from where to find relative files from :code:`list_file_paths` (Optional)"""
+        """List of files. For string format see :ref:`getters`."""
+        list_search_base_path: str = field(validator=validators.instance_of(str), factory=str)
+        """Base Path from where to find relative files from :code:`list_file_paths`.
+        You can also pass a template with keys from environment,
+        e.g.,  :code:`${<your environment variable>}`. The special key :code:`${LOGPREP_LIST}`
+        will be filled by this processor. """
 
     def __init__(self, filter_rule: FilterExpression, config: dict):
         super().__init__(filter_rule, config)
@@ -71,7 +74,6 @@ class ListComparisonRule(FieldManagerRule):
     def _get_list_search_base_path(self, list_search_base_path):
         if list_search_base_path is None:
             return self._config.list_search_base_path
-        list_search_base_path = Path(list_search_base_path)
         if self._config.list_search_base_path > list_search_base_path:
             return self._config.list_search_base_path
         return list_search_base_path
@@ -79,19 +81,33 @@ class ListComparisonRule(FieldManagerRule):
     def init_list_comparison(self, list_search_base_path: Optional[str] = None):
         """init method for list_comparision lists"""
         list_search_base_path = self._get_list_search_base_path(list_search_base_path)
+        if list_search_base_path.startswith("http"):
+            for list_path in self._config.list_file_paths:
+                list_search_base_path_resolved = Template(list_search_base_path).substitute(
+                    {**os.environ, **{"LOGPREP_LIST": list_path}}
+                )
+                content = GetterFactory.from_string(list_search_base_path_resolved).get()
+                compare_elements = content.splitlines()
+                file_elem_tuples = (elem for elem in compare_elements if not elem.startswith("#"))
+                self._compare_sets.update({list_path: set(file_elem_tuples)})
+            return
         absolute_list_paths = [
-            list_path for list_path in self._config.list_file_paths if list_path.is_absolute()
+            list_path for list_path in self._config.list_file_paths if list_path.startswith("/")
         ]
+        if not list_search_base_path.endswith("/"):
+            list_search_base_path = list_search_base_path + "/"
         converted_absolute_list_paths = [
-            list_search_base_path / list_path
+            list_search_base_path + list_path
             for list_path in self._config.list_file_paths
-            if not list_path.is_absolute()
+            if not list_path.startswith("/")
         ]
         list_paths = [*absolute_list_paths, *converted_absolute_list_paths]
         for list_path in list_paths:
-            compare_elements = list_path.read_text().splitlines()
-            file_elem_tuples = [elem for elem in compare_elements if not elem.startswith("#")]
-            self._compare_sets.update({list_path.name: set(file_elem_tuples)})
+            content = GetterFactory.from_string(list_path).get()
+            compare_elements = content.splitlines()
+            file_elem_tuples = (elem for elem in compare_elements if not elem.startswith("#"))
+            filename = os.path.basename(list_path)
+            self._compare_sets.update({filename: set(file_elem_tuples)})
 
     @property
     def compare_sets(self) -> dict:  # pylint: disable=missing-docstring
