@@ -15,7 +15,6 @@ Example
             - tests/testdata/labeler_rules/rules/
         specific_rules:
             - tests/testdata/labeler_rules/rules/
-        hash_salt: a_secret_tasty_ingredient
         regex_mapping: tests/testdata/unit/normalizer/normalizer_regex_mapping.yml
         html_replace_fields: tests/testdata/unit/normalizer/html_replace_fields.yml
         count_grok_pattern_matches:
@@ -41,16 +40,20 @@ from attr import define, field, validators
 from dateutil import parser
 from filelock import FileLock
 from pytz import timezone
-from ruamel.yaml import YAML
 
 from logprep.abc.processor import Processor
-from logprep.processor.base.exceptions import ProcessingWarning
-from logprep.processor.normalizer.exceptions import DuplicationError, NormalizerError
+from logprep.processor.base.exceptions import DuplicationError
 from logprep.processor.normalizer.rule import NormalizerRule
+from logprep.util.getter import GetterFactory
 from logprep.util.helper import add_field_to, get_dotted_field_value
-from logprep.util.validators import file_validator, directory_validator
+from logprep.util.validators import directory_validator
 
-yaml = YAML(typ="safe", pure=True)
+
+class NormalizerError(BaseException):
+    """Base class for Normalizer related exceptions."""
+
+    def __init__(self, name: str, message: str):
+        super().__init__(f"Normalizer ({name}): {message}")
 
 
 class Normalizer(Processor):
@@ -60,11 +63,13 @@ class Normalizer(Processor):
     class Config(Processor.Config):
         """config description for Normalizer"""
 
-        regex_mapping: str = field(validator=file_validator)
+        regex_mapping: str = field(validator=validators.instance_of(str))
         """Path to regex mapping file with regex keywords that are replaced with regex expressions
-            by the normalizer."""
-        html_replace_fields: Optional[str] = field(default=None, validator=file_validator)
-        """Path to yaml file with html replace fields"""
+            by the normalizer. For string format see :ref:`getters`."""
+        html_replace_fields: Optional[str] = field(
+            default=None, validator=[validators.optional(validators.instance_of(str))]
+        )
+        """Path to yaml file with html replace fields. For string format see :ref:`getters`"""
         count_grok_pattern_matches: Optional[dict] = field(
             default=None, validator=validators.optional(validators.instance_of(dict))
         )
@@ -124,12 +129,11 @@ class Normalizer(Processor):
 
         NormalizerRule.additional_grok_patterns = configuration.grok_patterns
 
-        with open(self._regex_mapping, "r", encoding="utf8") as file:
-            self._regex_mapping = yaml.load(file)
+        self._regex_mapping = GetterFactory.from_string(self._regex_mapping).get_yaml()
 
         if self._html_replace_fields:
-            with open(self._html_replace_fields, "r", encoding="utf8") as file:
-                self._html_replace_fields = yaml.load(file)
+            getter = GetterFactory.from_string(self._html_replace_fields)
+            self._html_replace_fields = getter.get_yaml()
         super().__init__(name=name, configuration=configuration, logger=logger)
 
     # pylint: enable=arguments-differ
@@ -222,10 +226,7 @@ class Normalizer(Processor):
         super().process(event)
         if self._count_grok_pattern_matches:
             self._write_grok_matches()
-        try:
-            self._raise_warning_if_fields_already_existed()
-        except DuplicationError as error:
-            raise ProcessingWarning(str(error)) from error
+        self._raise_warning_if_fields_already_existed()
 
     def _apply_rules(self, event, rule):
         """Normalizes Windows Event Logs.
