@@ -20,20 +20,15 @@ Example
         pre_detector_topic: sre_topic
         alert_ip_list_path: /tmp/ip_list.yml
 """
-import sys
+from functools import cached_property
 from logging import DEBUG, Logger
 from uuid import uuid4
 
 from attr import define, field, validators
-from logprep.abc import Processor
+
+from logprep.abc.processor import Processor
 from logprep.processor.pre_detector.ip_alerter import IPAlerter
 from logprep.processor.pre_detector.rule import PreDetectorRule
-from logprep.util.validators import file_validator
-
-if sys.version_info.minor < 8:  # pragma: no cover
-    from backports.cached_property import cached_property  # pylint: disable=import-error
-else:
-    from functools import cached_property
 
 
 class PreDetectorError(BaseException):
@@ -59,9 +54,12 @@ class PreDetector(Processor):
         A Kafka topic for the detection results of the Predetector.
         Results in this topic can be linked to the original event via a `pre_detector_id`.
         """
-        alert_ip_list_path: str = field(default=None, validator=file_validator)
+        alert_ip_list_path: str = field(
+            default=None, validator=validators.optional(validators.instance_of(str))
+        )
         """
         Path to a YML file or a list of paths to YML files with dictionaries of IPs.
+        For string format see :ref:`getters`.
         It is used by the Predetector to throw alerts if one of the IPs is found
         in fields that were defined in a rule.
 
