@@ -29,29 +29,22 @@ Example
 """
 import datetime
 import re
-import sys
+from functools import cached_property
 from logging import Logger
 from typing import Any, List, Optional, Tuple, Union
 from urllib.parse import parse_qs
 
 from attr import define, field, validators
-from ruamel.yaml import YAML
 from tldextract import TLDExtract
 from urlextract import URLExtract
 
-from logprep.abc import Processor
+from logprep.abc.processor import Processor
 from logprep.processor.pseudonymizer.encrypter import DualPKCS1HybridEncrypter
-from logprep.processor.pseudonymizer.rule import PseudonymizeRule
+from logprep.processor.pseudonymizer.rule import PseudonymizerRule
 from logprep.util.cache import Cache
+from logprep.util.getter import GetterFactory
 from logprep.util.hasher import SHA256Hasher
-from logprep.util.validators import file_validator, list_of_urls_validator
-
-if sys.version_info.minor < 8:  # pragma: no cover
-    from backports.cached_property import cached_property  # pylint: disable=import-error
-else:
-    from functools import cached_property
-
-yaml = YAML(typ="safe", pure=True)
+from logprep.util.validators import list_of_urls_validator
 
 
 class Pseudonymizer(Processor):
@@ -67,22 +60,22 @@ class Pseudonymizer(Processor):
         These are not the pseudonymized events, but just the pseudonyms with the encrypted real
         values.
         """
-        pubkey_analyst: str = field(validator=file_validator)
+        pubkey_analyst: str = field(validator=validators.instance_of(str))
         """
-        Path to the public key of an analyst.
+        Path to the public key of an analyst. For string format see :ref:`getters`.
 
         * /var/git/analyst_pub.pem"""
-        pubkey_depseudo: str = field(validator=file_validator)
+        pubkey_depseudo: str = field(validator=validators.instance_of(str))
         """
-        Path to the public key for depseudonymization
+        Path to the public key for depseudonymization. For string format see :ref:`getters`.
 
         * /var/git/depseudo_pub.pem
         """
         hash_salt: str = field(validator=validators.instance_of(str))
         """A salt that is used for hashing."""
-        regex_mapping: str = field(validator=file_validator)
+        regex_mapping: str = field(validator=validators.instance_of(str))
         """
-        Path to a file with a regex mapping for pseudonymization, i.e.:
+        Path to a file (for string format see :ref:`getters`) with a regex mapping for pseudonymization, i.e.:
 
         * /var/git/logprep-rules/pseudonymizer_rules/regex_mapping.json
         """
@@ -133,7 +126,7 @@ class Pseudonymizer(Processor):
     HASH_PREFIX = "<pseudonym:"
     HASH_SUFFIX = ">"
 
-    rule_class = PseudonymizeRule
+    rule_class = PseudonymizerRule
 
     def __init__(self, name: str, configuration: Processor.Config, logger: Logger):
         super().__init__(name=name, configuration=configuration, logger=logger)
@@ -180,8 +173,7 @@ class Pseudonymizer(Processor):
             self._tld_extractor = TLDExtract()
 
     def _load_regex_mapping(self, regex_mapping_path: str):
-        with open(regex_mapping_path, "r", encoding="utf8") as file:
-            self._regex_mapping = yaml.load(file)
+        self._regex_mapping = GetterFactory.from_string(regex_mapping_path).get_yaml()
 
     def process(self, event: dict):
         self.pseudonymized_fields = set()
@@ -189,7 +181,7 @@ class Pseudonymizer(Processor):
         super().process(event)
         return (self.pseudonyms, self._config.pseudonyms_topic) if self.pseudonyms != [] else None
 
-    def _apply_rules(self, event: dict, rule: PseudonymizeRule):
+    def _apply_rules(self, event: dict, rule: PseudonymizerRule):
         for dotted_field, regex in rule.pseudonyms.items():
             if dotted_field not in self.pseudonymized_fields:
                 try:
