@@ -47,7 +47,7 @@ from logprep.util.helper import pop_dotted_field_value, add_and_overwrite
 from logprep.processor.base.rule import Rule
 
 
-class PseudonymizeRule(Rule):
+class PseudonymizerRule(Rule):
     """Check if documents match a filter."""
 
     @define(kw_only=True)
@@ -71,20 +71,20 @@ class PseudonymizeRule(Rule):
     def normalize_rule_dict(cls, rule):
         if rule.get("pseudonymizer", {}).get("pseudonyms") is None:
             pseudonyms = pop_dotted_field_value(rule, "pseudonymize")
-        if pseudonyms is not None:
-            add_and_overwrite(rule, "pseudonymize.pseudonyms", pseudonyms)
-            warnings.warn(
-                "pseudonymize is deprecated. Use pseudonymizer.pseudonyms instead",
-                DeprecationWarning,
-            )
+            if pseudonyms is not None:
+                add_and_overwrite(rule, "pseudonymizer.pseudonyms", pseudonyms)
+                warnings.warn(
+                    "pseudonymize is deprecated. Use pseudonymizer.pseudonyms instead",
+                    DeprecationWarning,
+                )
         if rule.get("pseudonymizer", {}).get("url_fields") is None:
             url_fields = pop_dotted_field_value(rule, "url_fields")
-        if url_fields is not None:
-            add_and_overwrite(rule, "pseudonymize.url_fields", url_fields)
-            warnings.warn(
-                "url_fields is deprecated. Use pseudonymizer.url_fields instead",
-                DeprecationWarning,
-            )
+            if url_fields is not None:
+                add_and_overwrite(rule, "pseudonymizer.url_fields", url_fields)
+                warnings.warn(
+                    "url_fields is deprecated. Use pseudonymizer.url_fields instead",
+                    DeprecationWarning,
+                )
 
     # pylint: disable=C0111
     @property
