@@ -3,13 +3,14 @@
 # pylint: disable=logging-fstring-interpolation
 import inspect
 import logging
-import os
 import sys
+import warnings
 from argparse import ArgumentParser
-from logging import getLogger, Logger, DEBUG, ERROR
+from logging import ERROR, Logger, getLogger
 from os.path import basename
 from pathlib import Path
 
+import requests
 from colorama import Fore
 
 from logprep._version import get_versions
@@ -23,6 +24,7 @@ from logprep.util.rule_dry_runner import DryRunner
 from logprep.util.schema_and_rule_checker import SchemaAndRuleChecker
 from logprep.util.time_measurement import TimeMeasurement
 
+warnings.simplefilter("always", DeprecationWarning)
 logging.captureWarnings(True)
 
 DEFAULT_LOCATION_CONFIG = "/etc/logprep/pipeline.yml"
@@ -88,8 +90,7 @@ def _run_logprep(arguments, logger: Logger):
         runner = Runner.get_runner()
         runner.set_logger(logger)
         runner.load_configuration(arguments.config)
-        if logger.isEnabledFor(DEBUG):  # pragma: no cover
-            logger.debug("Configuration loaded")
+        logger.debug("Configuration loaded")
         runner.start()
     # pylint: disable=broad-except
     except BaseException as error:
@@ -106,45 +107,57 @@ def get_processor_type_and_rule_class() -> dict:  # pylint: disable=missing-docs
     }
 
 
-def print_version_and_exit(args):
+def get_versions_string(args) -> str:
     """
     Prints the version and exists. If a configuration was found then it's version
     is printed as well
     """
     versions = get_versions()
-    print(f"logprep version: \t\t {versions['version']}")
-    if args.config and os.path.isfile(args.config):
+    padding = 25
+    version_string = f"{'python version:'.ljust(padding)}{sys.version.split()[0]}"
+    version_string += f"\n{'logprep version:'.ljust(padding)}{versions['version']}"
+    try:
         config = Configuration().create_from_yaml(args.config)
-        config_version = f"{config.get('version', 'unset')}, {os.path.abspath(args.config)}"
+    except FileNotFoundError:
+        config = Configuration()
+        config.path = args.config
+    if config:
+        config_version = f"{config.get('version', 'unset')}, {config.path}"
     else:
-        config_version = f"no configuration found in '{os.path.abspath(args.config)}'"
-    print(f"configuration version: \t {config_version}")
-    sys.exit(0)
+        config_version = f"no configuration found in '{config.path}'"
+    version_string += f"\n{'configuration version:'.ljust(padding)}{config_version}"
+    return version_string
 
 
-def main():
-    """Start the logprep runner."""
-    args = _parse_arguments()
+def _setup_logger(args, config):
+    try:
+        AggregatingLogger.setup(config, logger_disabled=args.disable_logging)
+        logger = AggregatingLogger.create("Logprep")
+        for version in get_versions_string(args).split("\n"):
+            logger.info(version)
+    except BaseException as error:  # pylint: disable=broad-except
+        getLogger("Logprep").exception(error)
+        sys.exit(1)
+    return logger
 
-    if args.version:
-        print_version_and_exit(args)
 
-    if not os.path.isfile(args.config):
+def _load_configuration(args):
+    try:
+        config = Configuration().create_from_yaml(args.config)
+    except FileNotFoundError:
         print(f"The given config file does not exist: {args.config}", file=sys.stderr)
         print(
             "Create the configuration or change the path. Use '--help' for more information.",
             file=sys.stderr,
         )
         sys.exit(1)
-
-    config = Configuration().create_from_yaml(args.config)
-    try:
-        AggregatingLogger.setup(config, logger_disabled=args.disable_logging)
-        logger = AggregatingLogger.create("Logprep")
-    except BaseException as error:  # pylint: disable=broad-except
-        getLogger("Logprep").exception(error)
+    except requests.RequestException as error:
+        print(f"{error}", file=sys.stderr)
         sys.exit(1)
+    return config
 
+
+def _verify_configuration(args, config, logger):
     try:
         if args.validate_rules or args.auto_test:
             config.verify_pipeline_only(logger)
@@ -156,27 +169,45 @@ def main():
         logger.exception(error)
         sys.exit(1)
 
+
+def _setup_metrics_and_time_measurement(args, config, logger):
     measure_time_config = config.get("metrics", {}).get("measure_time", {})
     TimeMeasurement.TIME_MEASUREMENT_ENABLED = measure_time_config.get("enabled", False)
     TimeMeasurement.APPEND_TO_EVENT = measure_time_config.get("append_to_event", False)
 
-    if logger.isEnabledFor(DEBUG):  # pragma: no cover
-        logger.debug(f'Metric export enabled: {config.get("metrics", {}).get("enabled", False)}')
-        logger.debug(f"Time measurement enabled: {TimeMeasurement.TIME_MEASUREMENT_ENABLED}")
-        logger.debug(f"Config path: {args.config}")
+    logger.debug(f'Metric export enabled: {config.get("metrics", {}).get("enabled", False)}')
+    logger.debug(f"Time measurement enabled: {TimeMeasurement.TIME_MEASUREMENT_ENABLED}")
+    logger.debug(f"Config path: {args.config}")
+
+
+def _validate_rules(args, logger):
+    type_rule_map = get_processor_type_and_rule_class()
+    rules_valid = []
+    for processor_type, rule_class in type_rule_map.items():
+        rules_valid.append(
+            SchemaAndRuleChecker().validate_rules(args.config, processor_type, rule_class, logger)
+        )
+    if not all(rules_valid):
+        sys.exit(1)
+    if not args.auto_test:
+        sys.exit(0)
+
+
+def main():
+    """Start the logprep runner."""
+    args = _parse_arguments()
+
+    if args.version:
+        print(get_versions_string(args))
+        sys.exit(0)
+
+    config = _load_configuration(args)
+    logger = _setup_logger(args, config)
+
+    _verify_configuration(args, config, logger)
     if args.validate_rules or args.auto_test:
-        type_rule_map = get_processor_type_and_rule_class()
-        rules_valid = []
-        for processor_type, rule_class in type_rule_map.items():
-            rules_valid.append(
-                SchemaAndRuleChecker().validate_rules(
-                    args.config, processor_type, rule_class, logger
-                )
-            )
-        if not all(rules_valid):
-            sys.exit(1)
-        if not args.auto_test:
-            sys.exit(0)
+        _validate_rules(args, logger)
+    _setup_metrics_and_time_measurement(args, config, logger)
 
     if args.auto_test:
         TimeMeasurement.TIME_MEASUREMENT_ENABLED = False
