@@ -2,9 +2,7 @@
 """This module implements an auto-tester that can execute tests for rules."""
 
 import hashlib
-import inspect
 import json
-import pathlib
 import sys
 import tempfile
 import traceback
@@ -15,23 +13,25 @@ from io import StringIO
 from logging import getLogger
 from os import walk, path
 from pprint import pprint
-from typing import Tuple
+from typing import Tuple, TYPE_CHECKING
+from logprep.framework.rule_tree.rule_tree import RuleTree
 
 from typing.io import TextIO
 import regex as re
 from colorama import Fore
 from ruamel.yaml import YAML, YAMLError
 
-from logprep.framework.rule_tree.rule_tree import RuleTree
-from logprep.processor.base.rule import Rule
 from logprep.processor.pre_detector.processor import PreDetector
 from logprep.processor.pseudonymizer.processor import Pseudonymizer
 from logprep.processor.list_comparison.processor import ListComparison
 from logprep.factory import Factory
 from logprep.util.grok_pattern_loader import GrokPatternLoader as gpl
-from logprep.abc import Processor
 from logprep.util.helper import print_fcolor, remove_file_if_exists, get_dotted_field_value
 
+if TYPE_CHECKING:
+    from logprep.abc.processor import Processor
+
+
 logger = getLogger()
 logger.disabled = True
 
@@ -169,7 +169,7 @@ class PreDetectionExtraHandler:
     """Used to handle special demands for PreDetector auto-tests."""
 
     @staticmethod
-    def _get_errors(processor: Processor, extra_output: tuple):
+    def _get_errors(processor: "Processor", extra_output: tuple):
         pd_errors = []
         pd_warnings = []
         if isinstance(processor, PreDetector):
@@ -334,7 +334,7 @@ class AutoRuleTester:
         return processor_uses_own_tests
 
     @staticmethod
-    def _get_rules(processor: Processor, rule_test: dict) -> dict:
+    def _get_rules(processor: "Processor", rule_test: dict) -> dict:
         if rule_test.get("rules"):
             return {"rules": rule_test.get("rules", [])}
         if rule_test.get("specific_rules") or rule_test.get("generic_rules"):
@@ -348,31 +348,31 @@ class AutoRuleTester:
             f"No rules provided for processor of type {processor.describe()}"
         )
 
-    def _add_rules_from_directory(self, processor: Processor, rule_type: str):
+    def _load_rules(self, processor: "Processor", rule_type: str):
         if rule_type == "rules":
-            processor.add_rules_from_directory(self._empty_rules_dirs)
+            processor.load_rules(self._empty_rules_dirs)
         elif rule_type == "specific_rules":
-            processor.add_rules_from_directory(self._empty_rules_dirs, [])
+            processor.load_rules(self._empty_rules_dirs, [])
         elif rule_type == "generic_rules":
-            processor.add_rules_from_directory([], self._empty_rules_dirs)
+            processor.load_rules([], self._empty_rules_dirs)
         self._do_processor_specific_setup(processor)
 
     @staticmethod
-    def _do_processor_specific_setup(processor: Processor):
+    def _do_processor_specific_setup(processor: "Processor"):
         if isinstance(processor, Pseudonymizer):
             processor._replace_regex_keywords_by_regex_expression()
-        elif isinstance(processor, ListComparison):
+        if isinstance(processor, ListComparison):
             processor._init_rules_list_comparison()
 
     def _prepare_test_eval(
-        self, processor: Processor, rule_dict: dict, rule_type: str, temp_rule_path: str
+        self, processor: "Processor", rule_dict: dict, rule_type: str, temp_rule_path: str
     ):
         self._create_rule_file(rule_dict, temp_rule_path)
         self._reset_trees(processor)
         self._clear_rules(processor)
-        self._add_rules_from_directory(processor, rule_type)
+        self._load_rules(processor, rule_type)
 
-    def _run_custom_rule_tests(self, processor: Processor, rule_test: dict):
+    def _run_custom_rule_tests(self, processor: "Processor", rule_test: dict):
         temp_rule_path = path.join(self._empty_rules_dirs[0], f"{hashlib.sha256()}.json")
         rules = self._get_rules(processor, rule_test)
 
@@ -382,7 +382,7 @@ class AutoRuleTester:
                 self._eval_custom_rule_test(rule_test, processor)
                 remove_file_if_exists(temp_rule_path)
 
-    def _run_file_rule_tests(self, processor: Processor, rule_test: dict):
+    def _run_file_rule_tests(self, processor: "Processor", rule_test: dict):
         temp_rule_path = path.join(self._empty_rules_dirs[0], f"{hashlib.sha256()}.json")
         rules = self._get_rules(processor, rule_test)
 
@@ -393,12 +393,12 @@ class AutoRuleTester:
                 remove_file_if_exists(temp_rule_path)
 
     @staticmethod
-    def _clear_rules(processor: Processor):
+    def _clear_rules(processor: "Processor"):
         if hasattr(processor, "_rules"):
             processor._rules.clear()  # pylint: disable=protected-access
 
     @staticmethod
-    def _reset_trees(processor: Processor):
+    def _reset_trees(processor: "Processor"):
         if hasattr(processor, "_tree"):
             processor._tree = RuleTree()
         if hasattr(processor, "_specific_tree"):
@@ -429,13 +429,13 @@ class AutoRuleTester:
             print_fcolor(Fore.LIGHTMAGENTA_EX, f'\nRULE FILE {rule_test["file"]}')
             self._filename_printed = True
 
-    def _eval_custom_rule_test(self, rule_test: dict, processor: Processor):
+    def _eval_custom_rule_test(self, rule_test: dict, processor: "Processor"):
         self._filename_printed = False
         with StringIO() as buf, redirect_stdout(buf):
             self._run_custom_tests(processor, rule_test)
             self._custom_tests_output += buf.getvalue()
 
-    def _eval_file_rule_test(self, rule_test: dict, processor: Processor, r_idx: int):
+    def _eval_file_rule_test(self, rule_test: dict, processor: "Processor", r_idx: int):
         self._filename_printed = False
 
         for t_idx, test in enumerate(rule_test["tests"]):
