@@ -104,6 +104,22 @@ def add_field_to(event, output_field, content, extends_lists=False, overwrite_ou
     return False
 
 
+def _get_slice_arg(slice_item):
+    return int(slice_item) if slice_item else None
+
+
+def _get_item(items, item):
+    try:
+        return dict.__getitem__(items, item)
+    except TypeError:
+        if ":" in item:
+            slice_args = map(_get_slice_arg, item.split(":"))
+            item = slice(*slice_args)
+        else:
+            item = int(item)
+        return list.__getitem__(items, item)
+
+
 def get_dotted_field_value(event: dict, dotted_field: str) -> Optional[Union[dict, list, str]]:
     """
     Returns the value of a requested dotted_field by iterating over the event dictionary until the
@@ -124,11 +140,15 @@ def get_dotted_field_value(event: dict, dotted_field: str) -> Optional[Union[dic
 
     fields = [event, *dotted_field.split(".")]
     try:
-        return reduce(dict.__getitem__, fields)
+        return reduce(_get_item, fields)
     except KeyError:
         return None
+    except ValueError:
+        return None
     except TypeError:
         return None
+    except IndexError:
+        return None
 
 
 def pop_dotted_field_value(event: dict, dotted_field: str) -> Optional[Union[dict, list, str]]:
@@ -248,9 +268,17 @@ def add_and_overwrite(event, target_field, content, *_):
 def append(event, target_field, content, separator):
     """appends to event"""
     target_value = get_dotted_field_value(event, target_field)
-    if isinstance(target_value, str):
-        separator = " " if separator is None else separator
+    if not isinstance(target_value, list):
+        target_value = "" if target_value is None else target_value
         target_value = f"{target_value}{separator}{content}"
         add_and_overwrite(event, target_field, target_value)
     else:
         append_as_list(event, target_field, content)
+
+
+def get_source_fields_dict(event, rule):
+    """returns a dict with dotted fields as keys and target values as values"""
+    source_fields = rule.source_fields
+    source_field_values = map(partial(get_dotted_field_value, event), source_fields)
+    source_field_dict = dict(zip(source_fields, source_field_values))
+    return source_field_dict
