@@ -2,6 +2,7 @@
 # pylint: disable=missing-docstring
 # pylint: disable=no-self-use
 # pylint: disable=line-too-long
+
 from logprep.filter.expression.filter_expression import Exists, StringFilterExpression
 from logprep.framework.rule_tree.node import Node
 from logprep.framework.rule_tree.rule_tree import RuleTree
@@ -160,11 +161,124 @@ class TestRuleTree:
             }
         )
         rule_tree.add_rule(rule2)
+        matchings_rules = rule_tree.get_matching_rules(
+            {"winlog": "123", "test": "Good", "foo": "bar"}
+        )
+        assert matchings_rules == [rule, rule2]
 
-        assert rule_tree.get_matching_rules({"winlog": "123", "test": "Good", "foo": "bar"}) == [
-            rule,
-            rule2,
-        ]
+    def test_match_rule_once_with_conjunction_like_sub_rule(self):
+        rule_tree = RuleTree()
+        rule = PreDetectorRule._create_from_dict(
+            {
+                "filter": "winlog OR winlog: 123",
+                "pre_detector": {
+                    "id": 1,
+                    "title": "1",
+                    "severity": "0",
+                    "case_condition": "directly",
+                    "mitre": [],
+                },
+            }
+        )
+        rule_tree.add_rule(rule)
+
+        assert rule_tree.get_matching_rules({"winlog": "123"}) == [rule]
+
+    def test_match_rule_once_with_conjunction_same(self):
+        rule_tree = RuleTree()
+        rule = PreDetectorRule._create_from_dict(
+            {
+                "filter": "winlog: 123 OR winlog: 123",
+                "pre_detector": {
+                    "id": 1,
+                    "title": "1",
+                    "severity": "0",
+                    "case_condition": "directly",
+                    "mitre": [],
+                },
+            }
+        )
+        rule_tree.add_rule(rule)
+
+        assert rule_tree.get_matching_rules({"winlog": "123"}) == [rule]
+
+    def test_match_rule_once_with_conjunction_both_match(self):
+        rule_tree = RuleTree()
+        rule = PreDetectorRule._create_from_dict(
+            {
+                "filter": "foo: 123 OR bar: 123",
+                "pre_detector": {
+                    "id": 1,
+                    "title": "1",
+                    "severity": "0",
+                    "case_condition": "directly",
+                    "mitre": [],
+                },
+            }
+        )
+        rule_tree.add_rule(rule)
+
+        assert rule_tree.get_matching_rules({"foo": "123", "bar": "123"}) == [rule]
+
+    def test_match_rule_with_conjunction_for_different_events(self):
+        rule_tree = RuleTree()
+        rule = PreDetectorRule._create_from_dict(
+            {
+                "filter": "winlog: 123 OR winlog: 456",
+                "pre_detector": {
+                    "id": 1,
+                    "title": "1",
+                    "severity": "0",
+                    "case_condition": "directly",
+                    "mitre": [],
+                },
+            }
+        )
+        rule_tree.add_rule(rule)
+
+        assert rule_tree.get_matching_rules({"winlog": "123"}) == [rule]
+        assert rule_tree.get_matching_rules({"winlog": "456"}) == [rule]
+
+    def test_match_two_identical_rules(self):
+        rule_tree = RuleTree()
+        rule = PreDetectorRule._create_from_dict(
+            {
+                "filter": "winlog: 123",
+                "pre_detector": {
+                    "id": 1,
+                    "title": "1",
+                    "severity": "0",
+                    "case_condition": "directly",
+                    "mitre": [],
+                },
+            }
+        )
+        rule_tree.add_rule(rule)
+        rule_tree.add_rule(rule)
+
+        assert rule_tree.get_matching_rules({"winlog": "123"}) == [rule]
+
+    def test_get_matching_rules_has_deterministic_order(self):
+        rule_tree = RuleTree()
+        test_rules = 5
+        for i in range(test_rules):
+            rule = PreDetectorRule._create_from_dict(
+                {
+                    "filter": "foo: 123 OR bar: 123",
+                    "pre_detector": {
+                        "id": i,
+                        "title": f"{i}",
+                        "severity": "0",
+                        "case_condition": "directly",
+                        "mitre": [],
+                    },
+                }
+            )
+            rule_tree.add_rule(rule)
+
+        matching_rules = rule_tree.get_matching_rules({"foo": "123", "bar": "123"})
+        rule_ids = [rule.detection_data["id"] for rule in matching_rules]
+        assert rule_ids == list(range(test_rules))
 
     def test_match_exists_filter_is_subfield(self):
         rule_tree = RuleTree()
@@ -212,9 +326,10 @@ class TestRuleTree:
         )
         rule_tree.add_rule(rule)
 
-        assert rule_tree.get_matching_rules({"abc": "DEF", "foo": {"bar": {"test": "567"}}}) == [
-            rule
-        ]
+        matching_rules = rule_tree.get_matching_rules(
+            {"abc": "DEF", "foo": {"bar": {"test": "567"}}}
+        )
+        assert matching_rules == [rule]
 
     def test_match_including_tags(self):
         tag_map = {"winlog": "WINDOWS"}
