@@ -4,26 +4,27 @@
 import re
 from copy import deepcopy
 from logging import DEBUG, WARNING, getLogger
-from multiprocessing import active_children, Lock
+from multiprocessing import Lock, active_children
 from unittest import mock
 
+import requests
 from _pytest.outcomes import fail
 from _pytest.python_api import raises
 
-from logprep.abc import Processor
+from logprep.abc.processor import Processor
 from logprep.abc.input import (
-    SourceDisconnectedError,
-    FatalInputError,
-    WarningInputError,
     CriticalInputError,
+    FatalInputError,
+    SourceDisconnectedError,
+    WarningInputError,
 )
-from logprep.abc.output import WarningOutputError, CriticalOutputError, FatalOutputError
+from logprep.abc.output import CriticalOutputError, FatalOutputError, WarningOutputError
 from logprep.factory import Factory
 from logprep.framework.pipeline import (
     MultiprocessingPipeline,
+    MustProvideALogHandlerError,
     MustProvideAnMPLogHandlerError,
     Pipeline,
-    MustProvideALogHandlerError,
     SharedCounter,
 )
 from logprep.metrics.metric import MetricTargets
@@ -68,6 +69,7 @@ class TestPipeline(ConfigurationForTests):
             log_handler=self.log_handler,
             lock=self.lock,
             shared_dict=self.shared_dict,
+            used_server_ports=mock.MagicMock(),
             metric_targets=self.metric_targets,
         )
 
@@ -81,12 +83,11 @@ class TestPipeline(ConfigurationForTests):
                     log_handler=not_a_log_handler,
                     lock=self.lock,
                     shared_dict=self.shared_dict,
+                    used_server_ports=mock.MagicMock(),
                     metric_targets=self.metric_targets,
                 )
 
-    def test_setup_builds_pipeline(self, mock_create):
-        assert len(self.pipeline._pipeline) == 0
-        self.pipeline._setup()
+    def test_pipeline_property_returns_pipeline(self, mock_create):
         assert len(self.pipeline._pipeline) == 2
         assert mock_create.call_count == 4  # 2 processors, 1 input, 1 output
 
@@ -103,13 +104,6 @@ class TestPipeline(ConfigurationForTests):
         for processor in processors:
             processor.shut_down.assert_called()
 
-    def test_setup_creates_connectors(self, _):
-        assert self.pipeline._input is None
-        assert self.pipeline._output is None
-        self.pipeline._setup()
-        assert self.pipeline._input is not None
-        assert self.pipeline._output is not None
-
     def test_setup_calls_setup_on_input_and_output(self, _):
         self.pipeline._setup()
         self.pipeline._input.setup.assert_called()
@@ -118,13 +112,11 @@ class TestPipeline(ConfigurationForTests):
     def test_passes_timeout_parameter_to_inputs_get_next(self, _):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({}, {})
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         timeout = self.logprep_config.get("timeout")
         self.pipeline._input.get_next.assert_called_with(timeout)
 
     def test_empty_documents_are_not_forwarded_to_other_processors(self, _):
-        assert len(self.pipeline._pipeline) == 0
-        self.pipeline._setup()
         input_data = [{"do_not_delete": "1"}, {"delete_me": "2"}, {"do_not_delete": "3"}]
         connector_config = {"dummy": {"type": "dummy_input", "documents": input_data}}
         input_connector = original_create(connector_config, mock.MagicMock())
@@ -143,10 +135,9 @@ class TestPipeline(ConfigurationForTests):
         deleter_rule = DeleterRule._create_from_dict({"filter": "delete_me", "delete": True})
         deleter_processor._specific_tree.add_rule(deleter_rule)
         self.pipeline._pipeline = [mock.MagicMock(), deleter_processor, mock.MagicMock()]
-        self.pipeline._create_logger()
         self.pipeline._logger.setLevel(DEBUG)
         while self.pipeline._input._documents:
-            self.pipeline._retrieve_and_process_data()
+            self.pipeline._process_pipeline()
         assert len(input_data) == 0, "all events were processed"
         assert self.pipeline._pipeline[0].process.call_count == 3, "called for all events"
         assert self.pipeline._pipeline[2].process.call_count == 2, "not called for deleted event"
@@ -158,7 +149,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
         self.pipeline._output.store = mock.MagicMock()
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert self.pipeline._output.store.call_count == 0
 
     def test_setup_calls_setup_on_input(self, _):
@@ -221,7 +212,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._output = original_create(
             {"dummy": {"type": "dummy_output"}}, mock.MagicMock()
         )
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert len(self.pipeline._output.events) == 0
         mock_error.assert_called()
         assert re.search(
@@ -237,7 +228,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"order": 1}, None)
         self.pipeline._output.store.side_effect = raise_critical_output_error
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._output.store_failed.assert_called()
         mock_error.assert_called()
         assert re.search(
@@ -250,11 +241,11 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._input.metrics = mock.MagicMock()
         self.pipeline._input.metrics.number_of_warnings = 0
         self.pipeline._input.get_next.return_value = ({"order": 1}, None)
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.get_next.side_effect = WarningInputError
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.get_next.side_effect = None
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert self.pipeline._input.get_next.call_count == 3
         assert mock_warning.call_count == 1
         assert self.pipeline._output.store.call_count == 2
@@ -266,11 +257,11 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._input.get_next.return_value = ({"order": 1}, None)
         self.pipeline._output.metrics = mock.MagicMock()
         self.pipeline._output.metrics.number_of_warnings = 0
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._output.store.side_effect = WarningOutputError
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._output.store.side_effect = None
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert self.pipeline._input.get_next.call_count == 3
         assert mock_warning.call_count == 1
         assert self.pipeline._output.store.call_count == 3
@@ -281,9 +272,9 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
         self.pipeline._pipeline[1].process.side_effect = ProcessorWarningMockError
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         mock_warning.assert_called()
         assert (
             "ProcessorWarningMockError" in mock_warning.call_args[0][0]
@@ -305,7 +296,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
         self.pipeline._pipeline[0].process.side_effect = ProcessingWarningMockCollection
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert mock_warning.call_count == 4, "called 2 times for 2 processors in pipeline"
         assert self.pipeline._output.store.call_count == 1, "the event is processed"
 
@@ -316,9 +307,9 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
         self.pipeline._pipeline[1].process.side_effect = Exception
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert self.pipeline._input.get_next.call_count == 2, "2 events gone into processing"
         assert mock_error.call_count == 2, "two errors occured"
         assert (
@@ -339,7 +330,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._input.metrics.number_of_errors = 0
         self.pipeline._input.get_next.return_value = ({"message": "test"}, None)
         self.pipeline._input.get_next.side_effect = raise_critical
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.get_next.assert_called()
         mock_error.assert_called()
         assert re.search(
@@ -356,7 +347,7 @@ class TestPipeline(ConfigurationForTests):
 
         self.pipeline._setup()
         self.pipeline._input.get_next.side_effect = raise_warning
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.get_next.assert_called()
         mock_warning.assert_called()
         assert re.search(
@@ -373,7 +364,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._output.metrics = mock.MagicMock()
         self.pipeline._output.metrics.number_of_errors = 0
         self.pipeline._output.store.side_effect = raise_critical
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._output.store_failed.assert_called()
         mock_error.assert_called()
         assert re.search(
@@ -387,7 +378,7 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"some": "event"}, None)
         self.pipeline._output.store.side_effect = WarningOutputError("mock output warning")
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._output.store.assert_called()
         mock_warning.assert_called()
         assert mock_warning.call_args[0][0].startswith(
@@ -428,7 +419,7 @@ class TestPipeline(ConfigurationForTests):
         processor_with_extra_data.process = mock.MagicMock()
         processor_with_extra_data.process.return_value = ([{"foo": "bar"}], "target")
         self.pipeline._pipeline = [mock.MagicMock(), processor_with_extra_data, mock.MagicMock()]
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert self.pipeline._input.get_next.call_count == 1
         assert self.pipeline._output.store_custom.call_count == 1
         self.pipeline._output.store_custom.assert_called_with({"foo": "bar"}, "target")
@@ -440,7 +431,7 @@ class TestPipeline(ConfigurationForTests):
         processor_with_extra_data.process = mock.MagicMock()
         processor_with_extra_data.process.return_value = [([{"foo": "bar"}], "target")]
         self.pipeline._pipeline = [mock.MagicMock(), processor_with_extra_data, mock.MagicMock()]
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         assert self.pipeline._input.get_next.call_count == 1
         assert self.pipeline._output.store_custom.call_count == 1
         self.pipeline._output.store_custom.assert_called_with({"foo": "bar"}, "target")
@@ -505,11 +496,8 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline.metrics.pipeline = [mock_metrics_one, mock_metrics_two]
         assert self.pipeline.metrics.number_of_errors == 2
 
-    def test_create_connector_adds_versions_information_to_input_connector_config(
-        self, mock_create
-    ):
-        self.pipeline._create_logger()
-        self.pipeline._create_connectors()
+    def test_setup_adds_versions_information_to_input_connector_config(self, mock_create):
+        self.pipeline._setup()
         called_input_config = mock_create.call_args_list[0][0][0]["dummy"]
         assert "version_information" in called_input_config, "ensure version_information is added"
         assert "logprep" in called_input_config.get("version_information"), "ensure logprep key"
@@ -517,7 +505,7 @@ class TestPipeline(ConfigurationForTests):
         assert called_input_config.get("version_information").get("logprep"), "ensure values"
         assert called_input_config.get("version_information").get("configuration"), "ensure values"
 
-    def test_create_connectors_connects_output_with_input(self, _):
+    def test_setup_connects_output_with_input(self, _):
         self.pipeline._setup()
         assert self.pipeline._output.input_connector == self.pipeline._input
 
@@ -529,17 +517,76 @@ class TestPipeline(ConfigurationForTests):
         self.pipeline._input.batch_finished_callback = mock.MagicMock()
         self.pipeline._output.store = mock.MagicMock()
         self.pipeline._output.store.return_value = None
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._input.batch_finished_callback.assert_not_called()
 
     def test_retrieve_and_process_data_calls_store_failed_for_non_critical_error_message(self, _):
         self.pipeline._setup()
         self.pipeline._input.get_next.return_value = ({"some": "event"}, "This is non critical")
-        self.pipeline._retrieve_and_process_data()
+        self.pipeline._process_pipeline()
         self.pipeline._output.store_failed.assert_called_with(
             "This is non critical", {"some": "event"}, None
         )
 
+    def test_http_input_registers_to_shard_dict(self, _):
+        self.pipeline._setup()
+        self.pipeline._input.server.config.port = 9000
+        self.pipeline._used_server_ports = {}
+        self.pipeline._setup()
+        assert 9000 in self.pipeline._used_server_ports
+
+    def test_http_input_registers_increased_port_to_shard_dict(self, _):
+        self.pipeline._setup()
+        self.pipeline._input.server.config.port = 9000
+        self.pipeline._used_server_ports = {9000: "other_process_name"}
+        self.pipeline._setup()
+        assert 9001 in self.pipeline._used_server_ports
+
+    def test_http_input_removes_port_from_shard_dict_on_shut_down(self, _):
+        self.pipeline._setup()
+        self.pipeline._input.server.config.port = 9000
+        self.pipeline._used_server_ports = {}
+        self.pipeline._setup()
+        assert 9000 in self.pipeline._used_server_ports
+        self.pipeline._shut_down()
+        assert 9000 not in self.pipeline._used_server_ports
+
+    def test_http_input_registers_increased_port_to_shard_dict_after_shut_down(self, _):
+        self.pipeline._setup()
+        self.pipeline._input.server.config.port = 9000
+        self.pipeline._used_server_ports = {9000: "other_process_name"}
+        self.pipeline._setup()
+        assert 9001 in self.pipeline._used_server_ports
+        self.pipeline._shut_down()
+        assert 9001 not in self.pipeline._used_server_ports
+        self.pipeline._setup()
+        assert 9001 in self.pipeline._used_server_ports
+
+    def test_shut_down_drains_input_queues(self, _):
+        self.pipeline._setup()
+        input_config = {
+            "testinput": {
+                "type": "http_input",
+                "uvicorn_config": {
+                    "host": "127.0.0.1",
+                    "port": 9000,
+                    "ssl_certfile": "tests/testdata/acceptance/http_input/cert.crt",
+                    "ssl_keyfile": "tests/testdata/acceptance/http_input/cert.key",
+                },
+                "endpoints": {"/json": "json", "/jsonl": "jsonl", "/plaintext": "plaintext"},
+            }
+        }
+        self.pipeline._input = original_create(input_config, mock.MagicMock())
+        self.pipeline._input.messages.put({"message": "test message"})
+        assert self.pipeline._input.messages.qsize() == 1
+        self.pipeline._shut_down()
+        assert self.pipeline._input.messages.qsize() == 0
+
+    def test_pipeline_raises_http_error_from_factory_create(self, mock_create):
+        mock_create.side_effect = requests.HTTPError()
+        with raises(requests.HTTPError):
+            self.pipeline._setup()
+
 
 class TestMultiprocessingPipeline(ConfigurationForTests):
     def setup_class(self):
@@ -553,6 +600,7 @@ class TestMultiprocessingPipeline(ConfigurationForTests):
                     config=self.logprep_config,
                     log_handler=not_a_log_handler,
                     lock=self.lock,
+                    used_server_ports=mock.MagicMock(),
                     shared_dict=self.shared_dict,
                 )
 
@@ -563,6 +611,7 @@ class TestMultiprocessingPipeline(ConfigurationForTests):
                 config=self.logprep_config,
                 log_handler=self.log_handler,
                 lock=self.lock,
+                used_server_ports=mock.MagicMock(),
                 shared_dict=self.shared_dict,
             )
         except MustProvideAnMPLogHandlerError:
@@ -576,6 +625,7 @@ class TestMultiprocessingPipeline(ConfigurationForTests):
                 config=self.logprep_config,
                 log_handler=self.log_handler,
                 lock=self.lock,
+                used_server_ports=mock.MagicMock(),
                 shared_dict=self.shared_dict,
             )
         )
@@ -589,6 +639,7 @@ class TestMultiprocessingPipeline(ConfigurationForTests):
                 config=self.logprep_config,
                 log_handler=self.log_handler,
                 lock=self.lock,
+                used_server_ports=mock.MagicMock(),
                 shared_dict=self.shared_dict,
             )
         )
@@ -602,6 +653,7 @@ class TestMultiprocessingPipeline(ConfigurationForTests):
             config=self.logprep_config,
             log_handler=self.log_handler,
             lock=self.lock,
+            used_server_ports=mock.MagicMock(),
             shared_dict=self.shared_dict,
         )
         assert not pipeline._iterate()
