@@ -5,15 +5,17 @@ import json
 from abc import ABC
 from copy import deepcopy
 from logging import getLogger
+from pathlib import Path
 from typing import Iterable
 from unittest import mock
 
 import pytest
+import responses
+import requests
 from ruamel.yaml import YAML
 
 from logprep.abc.processor import Processor
 from logprep.factory import Factory
-from logprep.factory_error import InvalidConfigurationError
 from logprep.framework.rule_tree.rule_tree import RuleTree
 from logprep.processor.base.exceptions import ProcessingWarning
 from logprep.processor.processor_strategy import ProcessStrategy
@@ -154,38 +156,67 @@ class BaseProcessorTestCase(ABC):
 
     @mock.patch("logging.Logger.isEnabledFor", return_value=True)
     @mock.patch("logging.Logger.debug")
-    def test_add_rules_from_directory_with_debug(self, mock_debug, _):
-        self.object.add_rules_from_directory(
-            specific_rules_dirs=self.specific_rules_dirs, generic_rules_dirs=self.generic_rules_dirs
+    def test_load_rules_with_debug(self, mock_debug, _):
+        self.object.load_rules(
+            specific_rules_targets=self.specific_rules_dirs,
+            generic_rules_targets=self.generic_rules_dirs,
         )
         mock_debug.assert_called()
 
-    def test_add_rules_from_directory(self):
+    def test_load_rules(self):
         self.object._generic_tree = RuleTree()
         self.object._specific_tree = RuleTree()
         generic_rules_size = self.object._generic_tree.get_size()
         specific_rules_size = self.object._specific_tree.get_size()
-        self.object.add_rules_from_directory(
-            specific_rules_dirs=self.specific_rules_dirs, generic_rules_dirs=self.generic_rules_dirs
+        self.object.load_rules(
+            specific_rules_targets=self.specific_rules_dirs,
+            generic_rules_targets=self.generic_rules_dirs,
         )
         new_generic_rules_size = self.object._generic_tree.get_size()
         new_specific_rules_size = self.object._specific_tree.get_size()
         assert new_generic_rules_size > generic_rules_size
         assert new_specific_rules_size > specific_rules_size
 
+    def test_load_rules_calls_getter_factory(self):
+        with mock.patch("logprep.util.getter.GetterFactory.from_string") as getter_factory:
+            with pytest.raises(
+                TypeError, match="must be str, bytes or bytearray, not .*MagicMock.*"
+            ):
+                self.object.load_rules(
+                    specific_rules_targets=self.specific_rules_dirs,
+                    generic_rules_targets=self.generic_rules_dirs,
+                )
+            getter_factory.assert_called()
+
+    @responses.activate
+    def test_accepts_http_in_rules_config(self):
+        responses.add(responses.GET, "https://this.is.not.existent/bla.yml", mock.MagicMock())
+        responses.add(responses.GET, "http://does.not.matter", mock.MagicMock())
+        myconfig = deepcopy(self.CONFIG)
+        myconfig.update(
+            {"specific_rules": ["http://does.not.matter", "https://this.is.not.existent/bla.yml"]}
+        )
+        myconfig.update(
+            {"generic_rules": ["http://does.not.matter", "https://this.is.not.existent/bla.yml"]}
+        )
+        with pytest.raises(TypeError, match="not .*MagicMock.*"):
+            Factory.create({"http_rule_processor": myconfig}, self.logger)
+
     def test_no_redundant_rules_are_added_to_rule_tree(self):
         """
         prevents a kind of DDOS where a big amount of same rules are placed into
         in the rules directories
         ensures that every rule in rule tree is unique
         """
-        self.object.add_rules_from_directory(
-            specific_rules_dirs=self.specific_rules_dirs, generic_rules_dirs=self.generic_rules_dirs
+        self.object.load_rules(
+            specific_rules_targets=self.specific_rules_dirs,
+            generic_rules_targets=self.generic_rules_dirs,
         )
         generic_rules_size = self.object._generic_tree.get_size()
         specific_rules_size = self.object._specific_tree.get_size()
-        self.object.add_rules_from_directory(
-            specific_rules_dirs=self.specific_rules_dirs, generic_rules_dirs=self.generic_rules_dirs
+        self.object.load_rules(
+            specific_rules_targets=self.specific_rules_dirs,
+            generic_rules_targets=self.generic_rules_dirs,
         )
         new_generic_rules_size = self.object._generic_tree.get_size()
         new_specific_rules_size = self.object._specific_tree.get_size()
@@ -261,49 +292,26 @@ class BaseProcessorTestCase(ABC):
     def test_validation_raises_if_not_a_list(self, rule_list):
         config = deepcopy(self.CONFIG)
         config.update({rule_list: "i am not a list"})
-        with pytest.raises(InvalidConfigurationError, match=r"not a list"):
-            Factory.create({"test instance": config}, self.logger)
-
-    @pytest.mark.parametrize("rule_list", ["specific_rules", "generic_rules"])
-    def test_validation_raises_on_empty_rules_list(self, rule_list):
-        config = deepcopy(self.CONFIG)
-        config.update({rule_list: []})
-        with pytest.raises(InvalidConfigurationError, match=rf"{rule_list} is empty"):
+        with pytest.raises(TypeError, match=r"must be <class 'list'>"):
             Factory.create({"test instance": config}, self.logger)
 
     @pytest.mark.parametrize("rule_list", ["specific_rules", "generic_rules"])
     def test_validation_raises_if_elements_does_not_exist(self, rule_list):
         config = deepcopy(self.CONFIG)
         config.update({rule_list: ["/i/do/not/exist"]})
-        with pytest.raises(
-            InvalidConfigurationError, match=r"'\/i\/do\/not\/exist' does not exist"
-        ):
-            Factory.create({"test instance": config}, self.logger)
-
-    @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("os.path.isdir", return_value=False)
-    def test_validation_raises_if_element_is_not_a_directory(self, _, __):
-        config = deepcopy(self.CONFIG)
-        config.update({"specific_rules": ["/i/am/not/a/directory"]})
-        config.update({"generic_rules": ["/i/am/not/a/directory"]})
-        with pytest.raises(
-            InvalidConfigurationError, match=r"'\/i\/am\/not\/a\/directory' is not a directory"
-        ):
+        with pytest.raises(FileNotFoundError):
             Factory.create({"test instance": config}, self.logger)
 
     def test_validation_raises_if_tree_config_is_not_a_str(self):
         config = deepcopy(self.CONFIG)
         config.update({"tree_config": 12})
-        with pytest.raises(InvalidConfigurationError, match=r"tree_config is not a str"):
+        with pytest.raises(TypeError, match=r"must be <class 'str'>"):
             Factory.create({"test instance": config}, self.logger)
 
     def test_validation_raises_if_tree_config_is_not_exist(self):
         config = deepcopy(self.CONFIG)
         config.update({"tree_config": "/i/am/not/a/file/path"})
-        with pytest.raises(
-            InvalidConfigurationError,
-            match=r"tree_config file '\/i\/am\/not\/a\/file\/path' does not exist",
-        ):
+        with pytest.raises(FileNotFoundError):
             Factory.create({"test instance": config}, self.logger)
 
     def test_processor_metrics_counts_processed_events(self):
@@ -322,3 +330,22 @@ class BaseProcessorTestCase(ABC):
         self.object.process(event)
         assert self.object.metrics.mean_processing_time_per_event > 0
         assert self.object.metrics._mean_processing_time_sample_counter == 2
+
+    @responses.activate
+    def test_accepts_tree_config_from_http(self):
+        config = deepcopy(self.CONFIG)
+        config.update({"tree_config": "http://does.not.matter.bla/tree_config.yml"})
+        tree_config = Path("tests/testdata/unit/tree_config.json").read_text()
+        responses.add(responses.GET, "http://does.not.matter.bla/tree_config.yml", tree_config)
+        processor = Factory.create({"test instance": config}, self.logger)
+        assert processor._specific_tree._config_path == "http://does.not.matter.bla/tree_config.yml"
+        tree_config = json.loads(tree_config)
+        assert processor._specific_tree.priority_dict == tree_config.get("priority_dict")
+
+    @responses.activate
+    def test_raises_http_error(self):
+        config = deepcopy(self.CONFIG)
+        config.update({"tree_config": "http://does.not.matter.bla/tree_config.yml"})
+        responses.add(responses.GET, "http://does.not.matter.bla/tree_config.yml", status=404)
+        with pytest.raises(requests.HTTPError):
+            Factory.create({"test instance": config}, self.logger)
