@@ -1,14 +1,16 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
 from copy import deepcopy
+import hashlib
+from multiprocessing import current_process
 from os.path import exists
 from pathlib import Path
 from unittest import mock
 
 import pytest
-from requests import Response
+import responses
 
-from logprep.processor.base.exceptions import DuplicationError, ProcessingWarning
+from logprep.processor.base.exceptions import ProcessingWarning
 from logprep.factory import Factory
 from tests.unit.processor.base import BaseProcessorTestCase
 
@@ -33,7 +35,7 @@ class TestDomainResolver(BaseProcessorTestCase):
     def test_domain_to_ip_resolved_and_added(self, mock_gethostbyname):
         rule = {
             "filter": "fqdn",
-            "domain_resolver": {"source_url_or_domain": "fqdn"},
+            "domain_resolver": {"source_fields": ["fqdn"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -47,7 +49,7 @@ class TestDomainResolver(BaseProcessorTestCase):
     def test_domain_to_ip_resolved_and_added_from_cache(self, mock_gethostbyname):
         rule = {
             "filter": "fqdn",
-            "domain_resolver": {"source_url_or_domain": "fqdn"},
+            "domain_resolver": {"source_fields": ["fqdn"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -63,7 +65,7 @@ class TestDomainResolver(BaseProcessorTestCase):
     def test_url_to_ip_resolved_and_added(self, _):
         rule = {
             "filter": "url",
-            "domain_resolver": {"source_url_or_domain": "url"},
+            "domain_resolver": {"source_fields": ["url"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -78,7 +80,7 @@ class TestDomainResolver(BaseProcessorTestCase):
         self.object = Factory.create({"resolver": config}, self.logger)
         rule = {
             "filter": "url",
-            "domain_resolver": {"source_url_or_domain": "url"},
+            "domain_resolver": {"source_fields": ["url"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -94,7 +96,7 @@ class TestDomainResolver(BaseProcessorTestCase):
     def test_do_nothing_if_source_not_in_event(self):
         rule = {
             "filter": "url",
-            "domain_resolver": {"source_url_or_domain": "not_available"},
+            "domain_resolver": {"source_fields": ["not_available"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -110,7 +112,7 @@ class TestDomainResolver(BaseProcessorTestCase):
         self.object = Factory.create({"resolver": config}, self.logger)
         rule = {
             "filter": "url",
-            "domain_resolver": {"source_url_or_domain": "url"},
+            "domain_resolver": {"source_fields": ["url"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -130,7 +132,7 @@ class TestDomainResolver(BaseProcessorTestCase):
         self.object = Factory.create({"resolver": config}, self.logger)
         rule = {
             "filter": "url",
-            "domain_resolver": {"source_url_or_domain": "url"},
+            "domain_resolver": {"source_fields": ["url"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -152,7 +154,7 @@ class TestDomainResolver(BaseProcessorTestCase):
         self.object = Factory.create({"resolver": config}, self.logger)
         rule = {
             "filter": "url",
-            "domain_resolver": {"source_url_or_domain": "url"},
+            "domain_resolver": {"source_fields": ["url"]},
             "description": "",
         }
         self._load_specific_rule(rule)
@@ -161,11 +163,9 @@ class TestDomainResolver(BaseProcessorTestCase):
         self.object.process(document)
         assert document == expected
 
-    @mock.patch("requests.sessions.Session.get")
-    @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("os.path.isfile", return_value=True)
+    @responses.activate
     @mock.patch("socket.gethostbyname", return_value="1.2.3.4")
-    def test_resolves_with_tld_extract_tld_lists(self, _, __, ___, mock_get):
+    def test_resolves_with_tld_extract_tld_lists(self, _):
         response_content = """
 // at : https://en.wikipedia.org/wiki/.at
 // Confirmed by registry <it@nic.at> 2008-06-17
@@ -176,15 +176,12 @@ gv.at
 or.at
 sth.ac.at
         """
-        response = Response()
-        type(response).text = mock.PropertyMock(return_value=response_content)
-        type(response).status_code = mock.PropertyMock(return_value=200)
-        mock_get.return_value = response
+        responses.add(responses.GET, "http://does_not_matter", response_content)
         config = deepcopy(self.CONFIG)
-        config.update({"tld_lists": ["file://does_not_matter"]})
+        config.update({"tld_lists": ["http://does_not_matter"]})
         domain_resolver = Factory.create({"test instance": config}, self.logger)
-        document = {"url": "www.google.ac.at"}
-        expected = {"url": "www.google.ac.at", "resolved_ip": "1.2.3.4"}
+        document = {"url": "http://www.google.ac.at/some/text"}
+        expected = {"url": "http://www.google.ac.at/some/text", "resolved_ip": "1.2.3.4"}
         domain_resolver.process(document)
         assert document == expected
 
@@ -228,9 +225,10 @@ sth.ac.at
 
         # Due to duplication error logprep raises an ProcessingWarning
         with pytest.raises(
-            DuplicationError,
-            match=r"\('Test Instance Name', 'The following fields could not be written, "
-            r"because one or more subfields existed and could not be extended: resolved_ip'\)",
+            ProcessingWarning,
+            match=r"ProcessingWarning: \(Test Instance Name - The following fields could not be "
+            r"written, because one or more subfields existed and could not be extended: "
+            r"resolved_ip\)",
         ):
             self.object.process(document)
 
@@ -277,3 +275,19 @@ sth.ac.at
         self._load_specific_rule(rule_dict)
         self.object.process(document)
         assert document == expected
+
+    @responses.activate
+    def test_setup_downloads_tld_lists_to_separate_process_file(self):
+        tld_list = "http://db-path-target/list.dat"
+        tld_list_path = Path("/usr/bin/ls") if Path("/usr/bin/ls").exists() else Path("/bin/ls")
+        tld_list_content = tld_list_path.read_bytes()
+        expected_checksum = hashlib.md5(tld_list_content).hexdigest()  # nosemgrep
+        responses.add(responses.GET, tld_list, tld_list_content)
+        self.object._config.tld_lists = [tld_list]
+        self.object.setup()
+        downloaded_file = Path(f"{current_process().name}-{self.object.name}-tldlist-0.dat")
+        assert downloaded_file.exists()
+        downloaded_checksum = hashlib.md5(downloaded_file.read_bytes()).hexdigest()  # nosemgrep
+        assert expected_checksum == downloaded_checksum
+        # delete testfile
+        downloaded_file.unlink()
