@@ -24,7 +24,7 @@ class TestDropper(BaseProcessorTestCase):
         return self.CONFIG["generic_rules"]
 
     def test_dropper_instantiates(self):
-        rule = {"filter": "drop_me", "drop": ["drop_me"]}
+        rule = {"filter": "drop_me", "dropper": {"drop": ["drop_me"]}}
         self._load_specific_rule(rule)
         assert isinstance(self.object, Dropper)
 
@@ -36,7 +36,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_nested_field_gets_dropped(self):
-        rule = {"filter": "drop.me", "drop": ["drop.me"]}
+        rule = {"filter": "drop.me", "dropper": {"drop": ["drop.me"]}}
         expected = {}
         document = {"drop": {"me": "something"}}
         self._load_specific_rule(rule)
@@ -45,7 +45,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_nested_field_with_neighbour_gets_dropped(self):
-        rule = {"filter": "keep_me.drop_me", "drop": ["keep_me.drop_me"]}
+        rule = {"filter": "keep_me.drop_me", "dropper": {"drop": ["keep_me.drop_me"]}}
         expected = {"keep_me": {"keep_me_too": "something"}}
         document = {"keep_me": {"drop_me": "something", "keep_me_too": "something"}}
         self._load_specific_rule(rule)
@@ -54,7 +54,10 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_gets_dropped(self):
-        rule = {"filter": "keep_me.drop.me", "drop": ["keep_me.drop.me"], "drop_full": False}
+        rule = {
+            "filter": "keep_me.drop.me",
+            "dropper": {"drop": ["keep_me.drop.me"], "drop_full": False},
+        }
         expected = {"keep_me": {"drop": {}}}
         document = {"keep_me": {"drop": {"me": "something"}}}
         self._load_specific_rule(rule)
@@ -63,7 +66,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_gets_dropped_fully(self):
-        rule = {"filter": "please.drop.me.fully", "drop": ["please.drop.me.fully"]}
+        rule = {"filter": "please.drop.me.fully", "dropper": {"drop": ["please.drop.me.fully"]}}
         expected = {}
         document = {"please": {"drop": {"me": {"fully": "something"}}}}
         self._load_specific_rule(rule)
@@ -72,7 +75,10 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_with_neighbour_gets_dropped(self):
-        rule = {"filter": "keep_me.drop.me", "drop": ["keep_me.drop.me"], "drop_full": False}
+        rule = {
+            "filter": "keep_me.drop.me",
+            "dropper": {"drop": ["keep_me.drop.me"], "drop_full": False},
+        }
         expected = {"keep_me": {"drop": {}, "keep_me_too": "something"}}
         document = {"keep_me": {"drop": {"me": "something"}, "keep_me_too": "something"}}
         self._load_specific_rule(rule)
@@ -81,7 +87,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_nested_field_with_child_gets_dropped(self):
-        rule = {"filter": "drop.child", "drop": ["drop"]}
+        rule = {"filter": "drop.child", "dropper": {"drop": ["drop"]}}
         expected = {}
         document = {"drop": {"child": "something"}}
         self._load_specific_rule(rule)
@@ -90,7 +96,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_with_child_gets_dropped(self):
-        rule = {"filter": "drop.me", "drop": ["drop.me"]}
+        rule = {"filter": "drop.me", "dropper": {"drop": ["drop.me"]}}
         expected = {}
         document = {"drop": {"me": {"child": "foo"}}}
         self._load_specific_rule(rule)
@@ -99,7 +105,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_with_child_and_neighbour_gets_dropped(self):
-        rule = {"filter": "drop.me", "drop": ["drop.me"]}
+        rule = {"filter": "drop.me", "dropper": {"drop": ["drop.me"]}}
         expected = {"drop": {"neighbour": "bar"}}
         document = {"drop": {"me": {"child": "foo"}, "neighbour": "bar"}}
         self._load_specific_rule(rule)
@@ -108,7 +114,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_with_child_and_not_drop_full_gets_partially_dropped(self):
-        rule = {"filter": "drop.me", "drop": ["drop.me"], "drop_full": False}
+        rule = {"filter": "drop.me", "dropper": {"drop": ["drop.me"], "drop_full": False}}
         expected = {"drop": {}}
         document = {"drop": {"me": {"child": "foo"}}}
         self._load_specific_rule(rule)
@@ -117,7 +123,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_deep_nested_field_with_child_neighbour_and_not_drop_full_gets_partially_dropped(self):
-        rule = {"filter": "drop.child", "drop": ["drop.child"], "drop_full": False}
+        rule = {"filter": "drop.child", "dropper": {"drop": ["drop.child"], "drop_full": False}}
         expected = {"drop": {"neighbour": "bar"}}
         document = {"drop": {"child": {"grand_child": "foo"}, "neighbour": "bar"}}
         self._load_specific_rule(rule)
@@ -126,7 +132,7 @@ class TestDropper(BaseProcessorTestCase):
         assert document == expected
 
     def test_apply_rules_is_called(self):
-        rule = {"filter": "drop.child", "drop": ["drop.child"], "drop_full": False}
+        rule = {"filter": "drop.child", "dropper": {"drop": ["drop.child"], "drop_full": False}}
         document = {"drop": {"child": {"grand_child": "foo"}, "neighbour": "bar"}}
         self._load_specific_rule(rule)
         with mock.patch(
