@@ -1,8 +1,10 @@
 # pylint: disable=protected-access
 # pylint: disable=missing-docstring
 # pylint: disable=unused-argument
+# pylint: disable=too-many-arguments
 import json
 import os
+import re
 import tempfile
 import time
 from copy import deepcopy
@@ -10,7 +12,7 @@ from unittest import mock
 
 import pytest
 
-from logprep.processor.generic_adder.processor import DuplicationError
+from logprep.processor.base.exceptions import ProcessingWarning
 from logprep.processor.generic_adder.rule import InvalidGenericAdderDefinition
 from logprep.factory import Factory
 from logprep.factory_error import InvalidConfigurationError
@@ -83,6 +85,295 @@ class DBMockNeverEmpty(DBMock):
 
 
 class TestGenericAdder(BaseProcessorTestCase):
+    test_cases = [  # testcase, rule, event, expected
+        (
+            "Add from file",
+            {
+                "filter": "add_list_generic_test",
+                "generic_adder": {
+                    "add_from_file": "tests/testdata/unit/generic_adder/additions_file.yml"
+                },
+            },
+            {"add_list_generic_test": "Test", "event_id": 123},
+            {
+                "add_list_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Add from file in list",
+            {
+                "filter": "add_lists_one_generic_test",
+                "generic_adder": {
+                    "add_from_file": ["tests/testdata/unit/generic_adder/additions_file.yml"]
+                },
+            },
+            {"add_lists_one_generic_test": "Test", "event_id": 123},
+            {
+                "add_lists_one_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Add from two files",
+            {
+                "filter": "add_lists_two_generic_test",
+                "generic_adder": {
+                    "add_from_file": [
+                        "tests/testdata/unit/generic_adder/additions_file.yml",
+                        "tests/testdata/unit/generic_adder/additions_file_2.yml",
+                    ]
+                },
+            },
+            {"add_lists_two_generic_test": "Test", "event_id": 123},
+            {
+                "add_lists_two_generic_test": "Test",
+                "event_id": 123,
+                "added_from_other_file": "some field from another file",
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Add from two files using only first existing file",
+            {
+                "filter": "add_first_existing_generic_test",
+                "generic_adder": {
+                    "add_from_file": [
+                        "tests/testdata/unit/generic_adder/additions_file.yml",
+                        "tests/testdata/unit/generic_adder/additions_file_2.yml",
+                    ],
+                    "only_first_existing_file": True,
+                },
+            },
+            {"add_first_existing_generic_test": "Test", "event_id": 123},
+            {
+                "add_first_existing_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Add from two files using only first existing file, but first file doesn't exist",
+            {
+                "filter": "add_first_existing_with_missing_generic_test",
+                "generic_adder": {
+                    "add_from_file": [
+                        "I_DO_NOT_EXIST",
+                        "tests/testdata/unit/generic_adder/additions_file.yml",
+                    ],
+                    "only_first_existing_file": True,
+                },
+            },
+            {
+                "add_first_existing_with_missing_generic_test": "Test",
+                "event_id": 123,
+            },
+            {
+                "add_first_existing_with_missing_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Add from rule definition",
+            {
+                "filter": "add_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    }
+                },
+                "description": "",
+            },
+            {"add_generic_test": "Test", "event_id": 123},
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Add to existing dict without conflict",
+            {
+                "filter": "add_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    }
+                },
+                "description": "",
+            },
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "dotted": {"i_exist": "already"},
+            },
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}, "i_exist": "already"},
+            },
+        ),
+        (
+            "Add to existing with setting overwrite",
+            {
+                "filter": "add_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    },
+                    "overwrite_target": True,
+                },
+            },
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some_non_dict",
+            },
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some value",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+        (
+            "Extend list field with 'extend_target_list' enabled",
+            {
+                "filter": "extend_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    },
+                    "extend_target_list": True,
+                },
+            },
+            {"extend_generic_test": "Test", "event_id": 123, "some_added_field": []},
+            {
+                "extend_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": ["some value"],
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+            },
+        ),
+    ]
+
+    failure_test_cases = [  # testcase, rule, event, expected, error_message
+        (
+            "Add to existing value with 'overwrite_target' disabled",
+            {
+                "filter": "add_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    },
+                    "overwrite_target": False,
+                },
+            },
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some_non_dict",
+            },
+            {
+                "add_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "some_non_dict",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+                "tags": ["_generic_adder_failure"],
+            },
+            re.escape(
+                "ProcessingWarning: (Test Instance Name - The following fields could not be "
+                + "written, because one or more subfields existed and could not be extended: "
+                + "some_added_field)"
+            ),
+        ),
+        (
+            "Extend list field with 'extend_target_list' disabled",
+            {
+                "filter": "extend_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    },
+                    "extend_target_list": False,
+                },
+            },
+            {"extend_generic_test": "Test", "event_id": 123, "some_added_field": []},
+            {
+                "extend_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": [],
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+                "tags": ["_generic_adder_failure"],
+            },
+            re.escape(
+                "ProcessingWarning: (Test Instance Name - The following fields could not be "
+                + "written, because one or more subfields existed and could not be extended: "
+                + "some_added_field)"
+            ),
+        ),
+        (
+            "Extend list field with 'extend_target_list' enabled, but non-list target",
+            {
+                "filter": "extend_generic_test",
+                "generic_adder": {
+                    "add": {
+                        "some_added_field": "some value",
+                        "another_added_field": "another_value",
+                        "dotted.added.field": "yet_another_value",
+                    },
+                    "extend_target_list": True,
+                },
+            },
+            {"extend_generic_test": "Test", "event_id": 123, "some_added_field": "not_a_list"},
+            {
+                "extend_generic_test": "Test",
+                "event_id": 123,
+                "some_added_field": "not_a_list",
+                "another_added_field": "another_value",
+                "dotted": {"added": {"field": "yet_another_value"}},
+                "tags": ["_generic_adder_failure"],
+            },
+            re.escape(
+                "ProcessingWarning: (Test Instance Name - The following fields could not be "
+                + "written, because one or more subfields existed and could not be extended: "
+                + "some_added_field)"
+            ),
+        ),
+    ]
 
     CONFIG = {
         "type": "generic_adder",
@@ -101,109 +392,22 @@ class TestGenericAdder(BaseProcessorTestCase):
     def test_db_table_is_none(self):
         assert self.object._db_table is None
 
-    def test_add_generic_fields(self):
-        assert self.object.metrics.number_of_processed_events == 0
-        expected = {
-            "add_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {"add_generic_test": "Test", "event_id": 123}
+    @pytest.mark.parametrize("testcase, rule, event, expected", test_cases)
+    def test_generic_adder_testcases(
+        self, testcase, rule, event, expected
+    ):  # pylint: disable=unused-argument
+        self._load_specific_rule(rule)
+        self.object.process(event)
+        assert event == expected
 
-        self.object.process(document)
-
-        assert document == expected
-
-    def test_add_generic_fields_from_file(self):
-        assert self.object.metrics.number_of_processed_events == 0
-        expected = {
-            "add_list_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {"add_list_generic_test": "Test", "event_id": 123}
-
-        self.object.process(document)
-
-        assert document == expected
-
-    def test_add_generic_fields_from_file_list_one_element(self):
-        assert self.object.metrics.number_of_processed_events == 0
-        expected = {
-            "add_lists_one_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {"add_lists_one_generic_test": "Test", "event_id": 123}
-
-        self.object.process(document)
-
-        assert document == expected
-
-    def test_add_generic_fields_from_file_list_two_elements(self):
-        assert self.object.metrics.number_of_processed_events == 0
-        expected = {
-            "add_lists_two_generic_test": "Test",
-            "event_id": 123,
-            "added_from_other_file": "some field from another file",
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {"add_lists_two_generic_test": "Test", "event_id": 123}
-
-        self.object.process(document)
-
-        assert document == expected
-
-    def test_add_generic_fields_from_file_first_existing(self):
-        config = deepcopy(self.CONFIG)
-        config["generic_rules"] = [RULES_DIR_FIRST_EXISTING]
-        configuration = {"test processor": config}
-        generic_adder = Factory.create(configuration, self.logger)
-
-        assert generic_adder.metrics.number_of_processed_events == 0
-        expected = {
-            "add_first_existing_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {"add_first_existing_generic_test": "Test", "event_id": 123}
-
-        generic_adder.process(document)
-
-        assert document == expected
-
-    def test_add_generic_fields_from_file_first_existing_with_missing(self):
-        config = deepcopy(self.CONFIG)
-        config["specific_rules"] = [RULES_DIR_FIRST_EXISTING]
-        configuration = {"test_instance_name": config}
-        generic_adder = Factory.create(configuration, self.logger)
-
-        assert generic_adder.metrics.number_of_processed_events == 0
-        expected = {
-            "add_first_existing_with_missing_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {
-            "add_first_existing_with_missing_generic_test": "Test",
-            "event_id": 123,
-        }
-
-        generic_adder.process(document)
-
-        assert document == expected
+    @pytest.mark.parametrize("testcase, rule, event, expected, error_message", failure_test_cases)
+    def test_generic_adder_testcases_failure_handling(
+        self, testcase, rule, event, expected, error_message
+    ):
+        self._load_specific_rule(rule)
+        with pytest.raises(ProcessingWarning, match=error_message):
+            self.object.process(event)
+        assert event == expected, testcase
 
     def test_add_generic_fields_from_file_missing_and_existing_with_all_required(self):
         with pytest.raises(InvalidGenericAdderDefinition, match=r"files do not exist"):
@@ -217,49 +421,11 @@ class TestGenericAdder(BaseProcessorTestCase):
             InvalidGenericAdderDefinition,
             match=r"must be a dictionary with string values",
         ):
-
             config = deepcopy(self.CONFIG)
             config["generic_rules"] = [RULES_DIR_INVALID]
             configuration = {"test processor": config}
             Factory.create(configuration, self.logger)
 
-    def test_add_generic_fields_to_co_existing_field(self):
-        expected = {
-            "add_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some value",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}, "i_exist": "already"},
-        }
-        document = {
-            "add_generic_test": "Test",
-            "event_id": 123,
-            "dotted": {"i_exist": "already"},
-        }
-
-        self.object.process(document)
-
-        assert document == expected
-
-    def test_add_generic_fields_to_existing_value(self):
-        expected = {
-            "add_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some_non_dict",
-            "another_added_field": "another_value",
-            "dotted": {"added": {"field": "yet_another_value"}},
-        }
-        document = {
-            "add_generic_test": "Test",
-            "event_id": 123,
-            "some_added_field": "some_non_dict",
-        }
-
-        with pytest.raises(DuplicationError):
-            self.object.process(document)
-
-        assert document == expected
-
 
 class BaseTestGenericAdderSQLTestCase(BaseProcessorTestCase):
     def setup_method(self):
@@ -432,11 +598,12 @@ class TestGenericAdderProcessorSQLWithoutAddedTarget(BaseTestGenericAdderSQLTest
             "add_from_sql_db_table": "Test",
             "source": "TEST_0.test.123",
             "db": {"test": {"b": "foo", "c": "bar"}},
+            "tags": ["_generic_adder_failure"],
         }
         document = {"add_from_sql_db_table": "Test", "source": "TEST_0.test.123"}
 
         self.object.process(document)
-        with pytest.raises(DuplicationError):
+        with pytest.raises(ProcessingWarning):
             self.object.process(document)
 
         assert document == expected
