@@ -1,8 +1,10 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
 import pytest
+import responses
 
-from logprep.processor.list_comparison.processor import DuplicationError
+from logprep.factory import Factory
+from logprep.processor.base.exceptions import ProcessingWarning
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
@@ -122,10 +124,19 @@ class TestListComparison(BaseProcessorTestCase):
     def test_dotted_wrong_type(self):
         assert self.object.metrics.number_of_processed_events == 0
         document = {"dot_channel": "test", "user": "Franz", "dotted": "dotted_Franz"}
+        expected = {
+            "dot_channel": "test",
+            "user": "Franz",
+            "dotted": "dotted_Franz",
+            "tags": ["_list_comparison_failure"],
+            "user_results": {"in_list": ["user_list.txt"]},
+        }
 
-        with pytest.raises(DuplicationError):
+        with pytest.raises(ProcessingWarning):
             self.object.process(document)
 
+        assert document == expected
+
     def test_intermediate_output_field_is_wrong_type(self):
         assert self.object.metrics.number_of_processed_events == 0
         document = {
@@ -133,10 +144,19 @@ class TestListComparison(BaseProcessorTestCase):
             "user": "Franz",
             "dotted": {"user_results": ["do_not_look_here"]},
         }
+        expected = {
+            "tags": ["_list_comparison_failure"],
+            "dot_channel": "test",
+            "user": "Franz",
+            "dotted": {"user_results": ["do_not_look_here"]},
+            "user_results": {"in_list": ["user_list.txt"]},
+        }
 
-        with pytest.raises(DuplicationError):
+        with pytest.raises(ProcessingWarning):
             self.object.process(document)
 
+        assert document == expected
+
     def test_check_in_dotted_subfield(self):
         assert self.object.metrics.number_of_processed_events == 0
         document = {"channel": {"type": "fast"}}
@@ -177,6 +197,7 @@ class TestListComparison(BaseProcessorTestCase):
 
     def test_overwrite_target_field(self):
         document = {"user": "Franz"}
+        expected = {"user": "Franz", "tags": ["_list_comparison_failure"]}
         rule_dict = {
             "filter": "user",
             "list_comparison": {
@@ -190,8 +211,43 @@ class TestListComparison(BaseProcessorTestCase):
         self._load_specific_rule(rule_dict)
         self.object._init_rules_list_comparison()
         match = (
-            r"\('Test Instance Name', 'The following fields could not be written, because one "
-            r"or more subfields existed and could not be extended: user.in_list'\)"
+            r"ProcessingWarning: \(Test Instance Name - The following fields could not be written, "
+            r"because one or more subfields existed and could not be extended: user\.in_list\)"
         )
-        with pytest.raises(DuplicationError, match=match):
+        with pytest.raises(ProcessingWarning, match=match):
             self.object.process(document)
+
+        assert document == expected
+
+    @responses.activate
+    def test_list_comparison_loads_rule_with_http_template_in_list_search_base_path(self):
+        responses.add(
+            responses.GET,
+            "http://localhost/tests/testdata/bad_users.list?ref=bla",
+            """Franz
+Heinz
+Hans
+""",
+        )
+        rule_dict = {
+            "filter": "user",
+            "list_comparison": {
+                "source_fields": ["user"],
+                "target_field": "user_results",
+                "list_file_paths": ["bad_users.list"],
+            },
+            "description": "",
+        }
+        config = {
+            "type": "list_comparison",
+            "specific_rules": [],
+            "generic_rules": [],
+            "list_search_base_path": "http://localhost/tests/testdata/${LOGPREP_LIST}?ref=bla",
+        }
+        processor = Factory.create({"custom_lister": config}, self.logger)
+        rule = processor.rule_class._create_from_dict(rule_dict)
+        processor._specific_tree.add_rule(rule)
+        processor._init_rules_list_comparison()
+        assert processor._specific_rules[0].compare_sets == {
+            "bad_users.list": {"Franz", "Heinz", "Hans"}
+        }
