@@ -13,7 +13,7 @@ class TestRule:
         "file_data, raises",
         [
             (
-                """
+                b"""
                 filter: test_filter
                 rule:
                     regex_fields: []
@@ -22,7 +22,7 @@ class TestRule:
                 None,
             ),
             (
-                """
+                b"""
                 [
                     {
                         "filter": "test_filter",
@@ -33,7 +33,7 @@ class TestRule:
                 None,
             ),
             (
-                """
+                b"""
                 """,
                 (InvalidRuleDefinitionError, "no rules in file"),
             ),
@@ -41,13 +41,13 @@ class TestRule:
     )
     def test_create_rules_from_file(self, file_data, raises):
         mock_open = mock.mock_open(read_data=file_data)
-        with mock.patch("builtins.open", mock_open):
+        with mock.patch("pathlib.Path.open", mock_open):
             if raises:
                 error, message = raises
                 with pytest.raises(error, match=message):
-                    rules = Rule.create_rules_from_file("mock_path.json")
+                    rules = Rule.create_rules_from_target("mock_path.json")
             else:
-                rules = Rule.create_rules_from_file("mock_path.json")
+                rules = Rule.create_rules_from_target("mock_path.json")
                 assert isinstance(rules, list)
                 assert isinstance(rules[0], Rule)
                 rule = rules[0]
